@@ -27,6 +27,7 @@
 #include "csound_orc.h"
 #include <math.h>
 #include <ctype.h>
+#include <string.h>
 
 #include "oload.h"
 #include "insert.h"
@@ -35,8 +36,7 @@
 #include "typetabl.h"
 
 typedef struct NAME_ {
-    char          *namep;
-    struct NAME_  *nxt;
+    char          *namep;    struct NAME_  *nxt;
     int           type, count;
 } NAME;
 
@@ -54,6 +54,10 @@ typedef struct {
     int32      poolcount, strpool_cnt, argoffsize;
     int       nconsts;
     int       *constTbl;
+    int32     *typemask_tabl;
+    int32     *typemask_tabl_in, *typemask_tabl_out;
+    int       lgprevdef;
+    char      *filedir[101];
 } OTRAN_GLOBALS;
 
 static  int     gexist(CSOUND *, char *), gbloffndx(CSOUND *, char *);
@@ -61,14 +65,15 @@ static  int     lcloffndx(CSOUND *, char *);
 static  int     constndx(CSOUND *, const char *);
 static  int     strconstndx(CSOUND *, const char *);
 static  void    insprep(CSOUND *, INSTRTXT *);
-static  void    lgbuild(CSOUND *, char *);
+static  void    lgbuild(CSOUND *, char *, int inarg);
 static  void    gblnamset(CSOUND *, char *);
 static  int     plgndx(CSOUND *, char *);
 static  NAME    *lclnamset(CSOUND *, char *);
-        int     lgexist(CSOUND *, const char *);
+/*        int     lgexist(CSOUND *, const char *);*/
 static  void    delete_global_namepool(CSOUND *);
 static  void    delete_local_namepool(CSOUND *);
 static  int     pnum(char *s) ;
+static  int     lgexist2(CSOUND *csound, const char *s);
 
 extern void     print_tree(CSOUND *, char *, TREE *);
 
@@ -106,10 +111,59 @@ static void lblclear(CSOUND *csound)
 }
 #endif
 
+static void intyperr(CSOUND *csound, int n, char *s, char *opname,
+                     char tfound, char expect, int line)
+{
+    char    t[10];
+
+    switch (tfound) {
+    case 'w':
+    case 'f':
+    case 'a':
+    case 'k':
+    case 'i':
+    case 'P':
+    case 't':
+    case 'p': t[0] = tfound;
+      t[1] = '\0';
+      break;
+    case 'r':
+    case 'c': strcpy(t,"const");
+      break;
+    case 'S': strcpy(t,"string");
+      break;
+    case 'b':
+    case 'B': strcpy(t,"boolean");
+      break;
+    case '?': strcpy(t,"?");
+      break;
+  }
+    synterr(csound, Str("input arg %d '%s' of type %s not allowed when "
+                        "expecting %c (for opcode %s), line %d\n"),
+            n+1, s, t, expect, opname, line);
+}
+
+#if 0
+static void lblrequest(CSOUND *csound, char *s)
+{
+    /* for (req=0; req<ST(lblcnt); req++) */
+    /*   if (strcmp(ST(lblreq)[req].label,s) == 0) */
+    /*     return; */
+    /* if (++ST(lblcnt) >= ST(lblmax)) { */
+    /*   LBLREQ *tmp; */
+    /*   ST(lblmax) += LBLMAX; */
+    /*   tmp = mrealloc(csound, ST(lblreq), ST(lblmax) * sizeof(LBLREQ)); */
+    /*   ST(lblreq) = tmp; */
+    /* } */
+    /* ST(lblreq)[req].reqline = ST(curline); */
+    /* ST(lblreq)[req].label =s; */
+}
+#endif
+
 static inline void resetouts(CSOUND *csound)
 {
-    csound->acount = csound->kcount = csound->icount = 0;
-    csound->Bcount = csound->bcount = 0;
+    csound->acount = csound->kcount = csound->icount =
+      csound->Bcount = csound->bcount = 0;
 }
 
 /* Unused */
@@ -126,7 +180,7 @@ int tree_arg_list_count(TREE * root)
     int count = 0;
     TREE * current = root;
 
-    while(current != NULL) {
+    while (current != NULL) {
       current = current->next;
       count++;
     }
@@ -140,7 +194,7 @@ static OPTXT * last_optxt(OPTXT *optxt)
 {
     OPTXT *current = optxt;
 
-    while(current->nxtop != NULL) {
+    while (current->nxtop != NULL) {
       current = current->nxtop;
     }
     return current;
@@ -149,7 +203,7 @@ static OPTXT * last_optxt(OPTXT *optxt)
 /**
  * Append OPTXT op2 to end of OPTXT chain op1
  */
-static void append_optxt(OPTXT *op1, OPTXT *op2)
+static inline void append_optxt(OPTXT *op1, OPTXT *op2)
 {
     last_optxt(op1)->nxtop = op2;
 }
@@ -167,7 +221,7 @@ void update_lclcount(CSOUND *csound, INSTRTXT *ip, TREE *argslist)
 {
     TREE * current = argslist;
 
-    while(current != NULL) {
+    while (current != NULL) {
       switch(current->type) {
       case T_IDENT_S:
         ip->lclscnt++;
@@ -187,8 +241,8 @@ void update_lclcount(CSOUND *csound, INSTRTXT *ip, TREE *argslist)
       case T_IDENT_K:
       case T_IDENT_F:
       case T_IDENT_I:
-      case T_NUMBER:
-      case T_INTGR:
+      case NUMBER_TOKEN:
+      case INTEGER_TOKEN:
       default:
         ip->lclkcnt++;
         if (UNLIKELY(PARSER_DEBUG))
@@ -199,7 +253,7 @@ void update_lclcount(CSOUND *csound, INSTRTXT *ip, TREE *argslist)
 }
 */
 
-void set_xincod(CSOUND *csound, TEXT *tp, OENTRY *ep)
+void set_xincod(CSOUND *csound, TEXT *tp, OENTRY *ep, int line)
 {
     int n = tp->inlist->count;
     char *s;
@@ -219,9 +273,12 @@ void set_xincod(CSOUND *csound, TEXT *tp, OENTRY *ep)
     }
 
     while (n--) {                     /* inargs:   */
+      int32    tfound_m, treqd_m = 0L;
       s = tp->inlist->arg[n];
 
       if (n >= nreqd) {               /* det type required */
+        csound->DebugMsg(csound, "%s(%d): type required: %c\n",
+                         __FILE__, __LINE__, types[nreqd-1]);
         switch (types[nreqd-1]) {
         case 'M':
         case 'N':
@@ -232,55 +289,62 @@ void set_xincod(CSOUND *csound, TEXT *tp, OENTRY *ep)
         }
       }
       else treqd = types[n];          /*       or given)   */
+      csound->DebugMsg(csound, "%s(%d): treqd: %c\n", __FILE__, __LINE__, treqd);
       if (treqd == 'l') {             /* if arg takes lbl  */
         csound->DebugMsg(csound, "treqd = l");
-        /*lblrequest(csound, s);*/        /*      req a search */
+        //        lblrequest(csound, s);        /*      req a search */
         continue;                     /*      chk it later */
       }
       tfound = argtyp2(csound, s);     /* else get arg type */
       /* IV - Oct 31 2002 */
-      /*tfound_m = ST(typemask_tabl)[(unsigned char) tfound];
-        if (!(tfound_m & (ARGTYP_c|ARGTYP_p)) && !ST(lgprevdef) && *s != '"') {
-        synterr(csound, Str("input arg '%s' used before defined"), s);
-        }*/
-      csound->DebugMsg(csound, "treqd %c, tfound %c", treqd, tfound);
-      if (tfound == 'a' && n < 31)    /* JMC added for FOG */
-                                      /* 4 for FOF, 8 for FOG; expanded to 15  */
+      tfound_m = ST(typemask_tabl)[(unsigned char) tfound];
+      csound->DebugMsg(csound, "%s(%d): treqd: %c, tfound %c\n",
+                       __FILE__, __LINE__,treqd, tfound);
+      csound->DebugMsg(csound, "treqd %c, tfound_m %d ST(lgprevdef) %d\n",
+                       treqd, tfound_m, ST(lgprevdef));
+      if (!(tfound_m & (ARGTYP_c|ARGTYP_p)) && !ST(lgprevdef) && *s != '"') {
+        synterr(csound,
+                Str("input arg '%s' used before defined (in opcode %s),"
+                    " line %d\n"),
+                s, ep->opname, line);
+      }
+      if (tfound == 'a' && n < 31) /* JMC added for FOG */
+                                   /* 4 for FOF, 8 for FOG; expanded to 15  */
         tp->xincod |= (1 << n);
       if (tfound == 'S' && n < 31)
         tp->xincod_str |= (1 << n);
       /* IV - Oct 31 2002: simplified code */
-      /* if (!(tfound_m & ST(typemask_tabl_in)[(unsigned char) treqd])) { */
-      /* check for exceptional types */
-      /*switch (treqd) {*/
-      /*case 'Z':*/                             /* indef kakaka ... */
-      /*if (!(tfound_m & (n & 1 ? ARGTYP_a : ARGTYP_ipcrk)))
-        intyperr(csound, n, tfound, treqd);
-        break;
+      if (!(tfound_m & ST(typemask_tabl_in)[(unsigned char) treqd])) {
+        /* check for exceptional types */
+        switch (treqd) {
+        case 'Z':                             /* indef kakaka ... */
+          if (!(tfound_m & (n & 1 ? ARGTYP_a : ARGTYP_ipcrk)))
+            intyperr(csound, n, s, ep->opname, tfound, treqd, line);
+          break;
         case 'x':
-        treqd_m = ARGTYP_ipcr;*/              /* also allows i-rate */
-      /*case 's':*/                             /* a- or k-rate */
-      /*treqd_m |= ARGTYP_a | ARGTYP_k;
-        if (tfound_m & treqd_m) {
-        if (tfound == 'a' && tp->outlist != ST(nullist)) {*/
-      /*long outyp_m =*/                  /* ??? */
-      /*ST(typemask_tabl)[(unsigned char) argtyp(csound,
-        tp->outlist->arg[0])];
-        if (outyp_m & (ARGTYP_a | ARGTYP_w)) break;
-        }
-        else
-        break;
-        }
+          treqd_m = ARGTYP_ipcr;              /* also allows i-rate */
+        case 's':                             /* a- or k-rate */
+          treqd_m |= ARGTYP_a | ARGTYP_k;
+          if (tfound_m & treqd_m) {
+            if (tfound == 'a' && tp->outlist->count != 0) {
+              long outyp_m =                  /* ??? */
+                ST(typemask_tabl)[(unsigned char) argtyp2(csound,
+                                                          tp->outlist->arg[0])];
+              if (outyp_m & (ARGTYP_a | ARGTYP_w)) break;
+            }
+            else
+              break;
+          }
         default:
-        intyperr(csound, n, tfound, treqd);
-        break;
+          intyperr(csound, n, s, ep->opname, tfound, treqd, line);
+          break;
         }
-        }*/
+      }
     }
     csound->DebugMsg(csound, "xincod = %d", tp->xincod);
 }
 
-void set_xoutcod(CSOUND *csound, TEXT *tp, OENTRY *ep)
+void set_xoutcod(CSOUND *csound, TEXT *tp, OENTRY *ep, int line)
 {
     int n = tp->outlist->count;
     char *s;
@@ -290,7 +354,7 @@ void set_xoutcod(CSOUND *csound, TEXT *tp, OENTRY *ep)
 
     if (nreqd < 0)    /* for other opcodes */
       nreqd = strlen(types = ep->outypes);
-/*      if ((n != nreqd) &&       */        /* IV - Oct 24 2002: end of new code */
+/* if ((n != nreqd) && */        /* IV - Oct 24 2002: end of new code */
 /*          !(n > 0 && n < nreqd &&
             (types[n] == (char) 'm' || types[n] == (char) 'z' ||
              types[n] == (char) 'X' || types[n] == (char) 'N' ||
@@ -302,33 +366,36 @@ void set_xoutcod(CSOUND *csound, TEXT *tp, OENTRY *ep)
 
 
     while (n--) {                                     /* outargs:  */
-      /*        long    tfound_m;*/       /* IV - Oct 31 2002 */
+      long    tfound_m;       /* IV - Oct 31 2002 */
       s = tp->outlist->arg[n];
       treqd = types[n];
       tfound = argtyp2(csound, s);                     /*  found    */
       /* IV - Oct 31 2002 */
-      /*tfound_m = ST(typemask_tabl)[(unsigned char) tfound];*/
+      tfound_m = ST(typemask_tabl)[(unsigned char) tfound];
       /* IV - Sep 1 2002: xoutcod is the same as xincod for input */
       if (tfound == 'a' && n < 31)
         tp->xoutcod |= (1 << n);
       if (tfound == 'S' && n < 31)
         tp->xoutcod_str |= (1 << n);
       csound->DebugMsg(csound, "treqd %c, tfound %c", treqd, tfound);
-      /*if (tfound_m & ARGTYP_w)
-        if (ST(lgprevdef)) {
-        synterr(csound, Str("output name previously used, "
-        "type '%c' must be uniquely defined"), tfound);
-        }*/
+      /* if (tfound_m & ARGTYP_w) */
+      /*   if (ST(lgprevdef)) { */
+      /*     synterr(csound, Str("output name previously used, " */
+      /*                         "type '%c' must be uniquely defined, line %d"), */
+      /*             tfound, line); */
+      /*   } */
       /* IV - Oct 31 2002: simplified code */
-      /*if (!(tfound_m & ST(typemask_tabl_out)[(unsigned char) treqd])) {
-        synterr(csound, Str("output arg '%s' illegal type"), s);
-        }*/
+      if (!(tfound_m & ST(typemask_tabl_out)[(unsigned char) treqd])) {
+        synterr(csound, Str("output arg '%s' illegal type (for opcode %s),"
+                            " line %d\n"),
+                s, ep->opname, line);
+      }
     }
 }
 
 /**
  * Create an Opcode (OPTXT) from the AST node given. Called from
- * create_udo and create_instrument.
+ * create_instrument.
  */
 OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
 {
@@ -337,13 +404,15 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
     OPTXT *optxt, *retOptxt = NULL;
     char *arg;
     int opnum;
-    int n;
+    int n, nreqd;;
 
+    /* printf("%d(%d): tree=%p\n", __FILE__, __LINE__, root); */
+    /* print_tree(csound, "create_opcode", root); */
     optxt = (OPTXT *) mcalloc(csound, (int32)sizeof(OPTXT));
     tp = &(optxt->t);
 
     switch(root->type) {
-    case T_LABEL:
+    case LABEL_TOKEN:
       /* TODO - Need to verify here or elsewhere that this label is not
          already defined */
       tp->opnum = LABEL;
@@ -358,18 +427,29 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
       ip->opdstot += csound->opcodlst[LABEL].dsblksiz;
 
       break;
-    case T_GOTO:
-    case T_IGOTO:
-    case T_KGOTO:
+    case GOTO_TOKEN:
+    case IGOTO_TOKEN:
+    case KGOTO_TOKEN:
     case T_OPCODE:
     case T_OPCODE0:
-    case S_ASSIGN:
+    case '=':
       if (UNLIKELY(PARSER_DEBUG))
         csound->Message(csound,
                         "create_opcode: Found node for opcode %s\n",
                         root->value->lexeme);
 
-      opnum = find_opcode(csound, root->value->lexeme);
+      nreqd = tree_arg_list_count(root->left);   /* outcount */
+      /* replace opcode if needed */
+      if (!strcmp(root->value->lexeme, "xin") &&
+          nreqd > OPCODENUMOUTS_LOW) {
+        if (nreqd > OPCODENUMOUTS_HIGH)
+          opnum = find_opcode(csound, ".xin256");
+        else
+          opnum = find_opcode(csound, ".xin64");
+      }
+      else {
+        opnum = find_opcode(csound, root->value->lexeme);
+      }
 
       /* INITIAL SETUP */
       tp->opnum = opnum;
@@ -383,8 +463,8 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
         int outcount = tree_arg_list_count(root->left);
         int argcount = 0;
 
-//            csound->Message(csound, "Tree: In Count: %d\n", incount);
-//            csound->Message(csound, "Tree: Out Count: %d\n", outcount);
+        //    csound->Message(csound, "Tree: In Count: %d\n", incount);
+        //    csound->Message(csound, "Tree: Out Count: %d\n", outcount);
 
         size_t m = sizeof(ARGLST) + (incount - 1) * sizeof(char*);
         tp->inlist = (ARGLST*) mrealloc(csound, tp->inlist, m);
@@ -398,7 +478,7 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
         for (inargs = root->right; inargs != NULL; inargs = inargs->next) {
           /* INARGS */
 
-//                csound->Message(csound, "IN ARG TYPE: %d\n", inargs->type);
+          //      csound->Message(csound, "IN ARG TYPE: %d\n", inargs->type);
 
           arg = inargs->value->lexeme;
 
@@ -407,8 +487,10 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
           if ((n = pnum(arg)) >= 0) {
             if (n > ip->pmax)  ip->pmax = n;
           }
+          /* VL 14/12/11 : calling lgbuild here seems to be problematic for
+             undef arg checks */
           else {
-            lgbuild(csound, arg);
+            lgbuild(csound, arg, 1);
           }
 
 
@@ -416,24 +498,6 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
 
         /* update_lclcount(csound, ip, root->right); */
 
-        argcount = 0;
-
-        /* OUTARGS */
-        for (outargs = root->left; outargs != NULL; outargs = outargs->next) {
-
-          arg = outargs->value->lexeme;
-
-          tp->outlist->arg[argcount++] =
-            strsav_string(csound, arg);
-
-          if ((n = pnum(arg)) >= 0) {
-            if (n > ip->pmax)  ip->pmax = n;
-          }
-          else {
-            lgbuild(csound, arg);
-          }
-
-        }
       }
       /* update_lclcount(csound, ip, root->left); */
 
@@ -442,12 +506,35 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
 
       {
         OENTRY *ep = csound->opcodlst + tp->opnum;
-
+        int argcount = 0;
         //        csound->Message(csound, "Opcode InTypes: %s\n", ep->intypes);
         //        csound->Message(csound, "Opcode OutTypes: %s\n", ep->outypes);
 
-        set_xincod(csound, tp, ep);
-        set_xoutcod(csound, tp, ep);
+        for (outargs = root->left; outargs != NULL; outargs = outargs->next) {
+          arg = outargs->value->lexeme;
+          tp->outlist->arg[argcount++] = strsav_string(csound, arg);
+        }
+        set_xincod(csound, tp, ep, root->line);
+        /* OUTARGS */
+        for (outargs = root->left; outargs != NULL; outargs = outargs->next) {
+
+          arg = outargs->value->lexeme;
+
+          if ((n = pnum(arg)) >= 0) {
+            if (n > ip->pmax)  ip->pmax = n;
+          }
+          else {
+            if (arg[0] == 'w' &&
+                lgexist2(csound, arg) != 0) {
+              synterr(csound, Str("output name previously used, "
+                                  "type 'w' must be uniquely defined, line %d"),
+                      root->line);
+            }
+            lgbuild(csound, arg, 0);
+          }
+
+        }
+        set_xoutcod(csound, tp, ep, root->line);
 
         if (root->right != NULL) {
           if (ep->intypes[0] != 'l') {     /* intype defined by 1st inarg */
@@ -465,16 +552,16 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
           tp->pftype = tp->intype;
         }
 
-        //        csound->Message(csound,
-        //                        Str("create_opcode[%s]: opnum for opcode: %d\n"),
-        //                        root->value->lexeme, opnum);
+//        csound->Message(csound,
+//                        Str("create_opcode[%s]: opnum for opcode: %d\n"),
+//                        root->value->lexeme, opnum);
       }
       break;
     default:
       csound->Message(csound,
                       Str("create_opcode: No rule to handle statement of "
                           "type %d\n"), root->type);
-      print_tree(csound, NULL, root);
+      if (PARSER_DEBUG) print_tree(csound, NULL, root);
     }
 
     if (retOptxt == NULL) {
@@ -489,16 +576,6 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
 
 
 
-/**
- * Create a UDO (INSTRTXT) from the AST node given. Called from
- * csound_orc_compile.
- */
-INSTRTXT *create_udo(CSOUND *csound, TREE *root)
-{
-    INSTRTXT *ip = (INSTRTXT *) mcalloc(csound, sizeof(INSTRTXT));
-    return ip;
-}
-
 /**
  * Create an Instrument (INSTRTXT) from the AST node given for use as
  * Instrument0. Called from csound_orc_compile.
@@ -548,49 +625,50 @@ INSTRTXT *create_instrument0(CSOUND *csound, TREE *root)
     ip->t.inlist->arg[0] = strsav_string(csound, "0");
 
 
-    while(current != NULL) {
+    while (current != NULL) {
 
-      if (current->type != T_INSTR && current->type != T_UDO) {
+      if (current->type != INSTR_TOKEN && current->type != UDO_TOKEN) {
 
         if (UNLIKELY(PARSER_DEBUG))
           csound->Message(csound, "In INSTR 0: %s\n", current->value->lexeme);
 
-        if (current->type == S_ASSIGN
+        if (current->type == '='
            && strcmp(current->value->lexeme, "=.r") == 0) {
 
           MYFLT val = csound->pool[constndx(csound,
                                             current->right->value->lexeme)];
 
 
-          /* if (current->right->type == T_INTGR) {
+          /* if (current->right->type == INTEGER_TOKEN) {
              val = FL(current->right->value->value);
              } else {
              val = FL(current->right->value->fvalue);
              }*/
 
           /* modify otran defaults*/
-          if (current->left->type == T_SRATE) {
+          if (current->left->type == SRATE_TOKEN) {
             csound->tran_sr = val;
           }
-          else if (current->left->type == T_KRATE) {
+          else if (current->left->type == KRATE_TOKEN) {
             csound->tran_kr = val;
           }
-          else if (current->left->type == T_KSMPS) {
+          else if (current->left->type == KSMPS_TOKEN) {
             csound->tran_ksmps = val;
           }
-          else if (current->left->type == T_NCHNLS) {
+          else if (current->left->type == NCHNLS_TOKEN) {
             csound->tran_nchnls = current->right->value->value;
           }
-          else if (current->left->type == T_NCHNLSI) {
+          else if (current->left->type == NCHNLSI_TOKEN) {
             csound->tran_nchnlsi = current->right->value->value;
-            /* csound->Message(csound, "SETTING NCHNLS: %d\n", csound->tran_nchnls); */
+            /* csound->Message(csound, "SETTING NCHNLS: %d\n",
+                               csound->tran_nchnls); */
           }
-          else if (current->left->type == T_0DBFS) {
+          else if (current->left->type == ZERODBFS_TOKEN) {
             csound->tran_0dbfs = val;
-            csound->Message(csound, "SETTING 0DBFS: %f\n", csound->tran_0dbfs);
+            /* csound->Message(csound, "SETTING 0DBFS: %f\n",
+                               csound->tran_0dbfs); */
           }
 
-          /* TODO - Implement 0dbfs constant  -- surely done?? */
         }
 
         op->nxtop = create_opcode(csound, current, ip);
@@ -660,7 +738,7 @@ INSTRTXT *create_instrument(CSOUND *csound, TREE *root)
      * Note2: For now am not checking if root->left is a list (i.e. checking
      * root->left->next is NULL or not to indicate list)
      */
-    if (root->left->type == T_INTGR) { /* numbered instrument */
+    if (root->left->type == INTEGER_TOKEN) { /* numbered instrument */
       int32 instrNum = (int32)root->left->value->value; /* Not used! */
 
       c = csound->Malloc(csound, 10); /* arbritrarily chosen number of digits */
@@ -673,15 +751,17 @@ INSTRTXT *create_instrument(CSOUND *csound, TREE *root)
       ip->t.inlist->arg[0] = strsav_string(csound, c);
 
       csound->Free(csound, c);
-    } else if (root->left->type == T_IDENT) { /* named instrument */
+    } else if (root->left->type == T_IDENT &&
+               !(root->left->left != NULL &&
+                 root->left->left->type == UDO_ANS_TOKEN)) { /* named instrument */
       int32  insno_priority = -1L;
       c = root->left->value->lexeme;
 
       if (PARSER_DEBUG)
           csound->Message(csound, Str("create_instrument: instr name %s\n"), c);
 
-      if (UNLIKELY(*c == '+')) {
-        insno_priority--; c++;
+      if (UNLIKELY(root->left->rate == (int) '+')) {
+        insno_priority--;
       }
       /* IV - Oct 31 2002: some error checking */
       if (UNLIKELY(!check_instr_name(c))) {
@@ -751,7 +831,8 @@ void close_instrument(CSOUND *csound, INSTRTXT * ip)
           ip->lclkcnt = (ip->lclkcnt + 1) & (~1);
     }
 
-    ip->lclfixed = ip->lclkcnt + ip->lclwcnt * Wfloats * ip->lclpcnt * Pfloats;*/
+    ip->lclfixed = ip->lclkcnt +
+                   ip->lclwcnt * Wfloats * ip->lclpcnt * Pfloats;*/
 
     ip->mdepends = ip->mdepends >> 4;
 
@@ -796,125 +877,6 @@ void append_instrument(CSOUND * csound, INSTRTXT * instrtxt)
     current->nxtinstxt = instrtxt;
 }
 
-
-/* IV - Oct 12 2002: new function to parse arguments of opcode definitions */
-
-#if 0
-static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
-{
-    OPCODINFO   *inm = (OPCODINFO*) opc->useropinfo;
-    char    *types, *otypes;
-    int     i, i_incnt, a_incnt, k_incnt, i_outcnt, a_outcnt, k_outcnt, err;
-    int16   *a_inlist, *k_inlist, *i_inlist, *a_outlist, *k_outlist, *i_outlist;
-
-    /* count the number of arguments, and check types */
-    i = i_incnt = a_incnt = k_incnt = i_outcnt = a_outcnt = k_outcnt = err = 0;
-    types = inm->intypes; otypes = opc->intypes;
-    opc->dsblksiz = (uint16) sizeof(UOPCODE);
-    if (!strcmp(types, "0"))
-      types++;                  /* no input args */
-    while (*types) {
-      switch (*types) {
-      case 'a':
-        a_incnt++; *otypes++ = *types;
-        break;
-      case 'K':
-        i_incnt++;              /* also updated at i-time */
-      case 'k':
-        k_incnt++; *otypes++ = 'k';
-        break;
-      case 'i':
-      case 'o':
-      case 'p':
-      case 'j':
-        i_incnt++; *otypes++ = *types;
-        break;
-      default:
-        synterr(csound, Str("invalid input type for opcode %s"), inm->name);
-        err++; i--;
-      }
-      i++; types++;
-      if (i > OPCODENUMOUTS_MAX) {
-        synterr(csound, Str("too many input args for opcode %s"), inm->name);
-        csound->LongJmp(csound, 1);
-      }
-    }
-    *otypes++ = 'o'; *otypes = '\0';    /* optional arg for local ksmps */
-    inm->inchns = i;                    /* total number of input chnls */
-    inm->perf_incnt = a_incnt + k_incnt;
-    opc->dsblksiz += (uint16) (sizeof(MYFLT*) * i);
-    /* same for outputs */
-    i = 0;
-    types = inm->outtypes; otypes = opc->outypes;
-    if (!strcmp(types, "0"))
-      types++;                  /* no output args */
-    while (*types) {
-      if (i >= OPCODENUMOUTS_MAX) {
-        synterr(csound, Str("too many output args for opcode %s"), inm->name);
-        csound->LongJmp(csound, 1);
-      }
-      switch (*types) {
-      case 'a':
-        a_outcnt++; *otypes++ = *types;
-        break;
-      case 'K':
-        i_outcnt++;             /* also updated at i-time */
-      case 'k':
-        k_outcnt++; *otypes++ = 'k';
-        break;
-      case 'i':
-        i_outcnt++; *otypes++ = *types;
-        break;
-      default:
-        synterr(csound, Str("invalid output type for opcode %s"), inm->name);
-        err++; i--;
-      }
-      i++; types++;
-    }
-    *otypes = '\0';
-    inm->outchns = i;                   /* total number of output chnls */
-    inm->perf_outcnt = a_outcnt + k_outcnt;
-    opc->dsblksiz += (uint16) (sizeof(MYFLT*) * i);
-    opc->dsblksiz = ((opc->dsblksiz + (uint16) 15)
-                     & (~((uint16) 15)));   /* align (needed ?) */
-    /* now build index lists for the various types of arguments */
-    i = i_incnt + inm->perf_incnt + i_outcnt + inm->perf_outcnt;
-    i_inlist = inm->in_ndx_list = (int16*) mmalloc(csound,
-                                                   sizeof(int16) * (i + 6));
-    a_inlist = i_inlist + i_incnt + 1;
-    k_inlist = a_inlist + a_incnt + 1;
-    i = 0; types = inm->intypes;
-    while (*types) {
-      switch (*types++) {
-        case 'a': *a_inlist++ = i; break;
-        case 'k': *k_inlist++ = i; break;
-        case 'K': *k_inlist++ = i;      /* also updated at i-time */
-        case 'i':
-        case 'o':
-        case 'p':
-        case 'j': *i_inlist++ = i;
-      }
-      i++;
-    }
-    *i_inlist = *a_inlist = *k_inlist = -1;     /* put delimiters */
-    i_outlist = inm->out_ndx_list = k_inlist + 1;
-    a_outlist = i_outlist + i_outcnt + 1;
-    k_outlist = a_outlist + a_outcnt + 1;
-    i = 0; types = inm->outtypes;
-    while (*types) {
-      switch (*types++) {
-        case 'a': *a_outlist++ = i; break;
-        case 'k': *k_outlist++ = i; break;
-        case 'K': *k_outlist++ = i;     /* also updated at i-time */
-        case 'i': *i_outlist++ = i;
-      }
-      i++;
-    }
-    *i_outlist = *a_outlist = *k_outlist = -1;  /* put delimiters */
-    return err;
-}
-#endif
-
 static int pnum(char *s)        /* check a char string for pnum format  */
                                 /*   and return the pnum ( >= 0 )       */
 {                               /* else return -1                       */
@@ -958,7 +920,8 @@ void insert_instrtxt(CSOUND *csound, INSTRTXT *instrtxt, int32 instrNum) {
     csound->instrtxtp[instrNum] = instrtxt;
 }
 
-OPCODINFO *find_opcode_info(CSOUND *csound, char *opname) {
+OPCODINFO *find_opcode_info(CSOUND *csound, char *opname)
+{
     OPCODINFO *opinfo = csound->opcodeInfo;
     if (UNLIKELY(opinfo == NULL)) {
       csound->Message(csound, Str("!!! csound->opcodeInfo is NULL !!!\n"));
@@ -979,8 +942,9 @@ OPCODINFO *find_opcode_info(CSOUND *csound, char *opname) {
 /**
  * Compile the given TREE node into structs for Csound to use
  */
-void csound_orc_compile(CSOUND *csound, TREE *root) {
-    //    csound->Message(csound, "Begin Compiling AST (Currently Implementing)\n");
+void csound_orc_compile(CSOUND *csound, TREE *root)
+{
+//    csound->Message(csound, "Begin Compiling AST (Currently Implementing)\n");
 
     OPARMS      *O = csound->oparms;
     INSTRTXT    *instrtxt = NULL;
@@ -994,7 +958,7 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
 
     strsav_create(csound);
 
-    if (csound->otranGlobals == NULL) {
+    if (UNLIKELY(csound->otranGlobals == NULL)) {
       csound->otranGlobals = csound->Calloc(csound, sizeof(OTRAN_GLOBALS));
     }
     csound->instrtxtp = (INSTRTXT **) mcalloc(csound, (1 + csound->maxinsno)
@@ -1019,6 +983,27 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
     ST(constTbl) = (int*) mcalloc(csound, (256 + NCONSTS) * sizeof(int));
     constndx(csound, "0");
 
+    if (!ST(typemask_tabl)) {
+      const int32 *ptr = typetabl1;
+      ST(typemask_tabl) = (int32*) mcalloc(csound, sizeof(int32) * 256);
+      ST(typemask_tabl_in) = (int32*) mcalloc(csound, sizeof(int32) * 256);
+      ST(typemask_tabl_out) = (int32*) mcalloc(csound, sizeof(int32) * 256);
+      while (*ptr) {            /* basic types (both for input */
+        int32 pos = *ptr++;      /* and output) */
+        ST(typemask_tabl)[pos] = ST(typemask_tabl_in)[pos] =
+          ST(typemask_tabl_out)[pos] = *ptr++;
+      }
+      ptr = typetabl2;
+      while (*ptr) {            /* input types */
+        int32 pos = *ptr++;
+        ST(typemask_tabl_in)[pos] = *ptr++;
+      }
+      ptr = typetabl3;
+      while (*ptr) {            /* output types */
+        int32 pos = *ptr++;
+        ST(typemask_tabl_out)[pos] = *ptr++;
+      }
+    }
     instr0 = create_instrument0(csound, root);
     prvinstxt = prvinstxt->nxtinstxt = instr0;
     insert_instrtxt(csound, instr0, 0);
@@ -1027,10 +1012,10 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
 
       switch (current->type) {
       case T_INIT:
-      case S_ASSIGN:
+      case '=':
         /* csound->Message(csound, "Assignment found\n"); */
         break;
-      case T_INSTR:
+      case INSTR_TOKEN:
         /* csound->Message(csound, "Instrument found\n"); */
 
         resetouts(csound); /* reset #out counts */
@@ -1040,12 +1025,12 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
 
         prvinstxt = prvinstxt->nxtinstxt = instrtxt;
 
-        /* Handle Inserting into CSOUND here by checking id's (name or
+        /* Handle Inserting into CSOUND here by checking ids (name or
          * numbered) and using new insert_instrtxt?
          */
         //printf("Starting to install instruments\n");
         /* Temporarily using the following code */
-        if (current->left->type == T_INTGR) { /* numbered instrument */
+        if (current->left->type == INTEGER_TOKEN) { /* numbered instrument */
           int32 instrNum = (int32)current->left->value->value;
 
           insert_instrtxt(csound, instrtxt, instrNum);
@@ -1054,22 +1039,56 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
           TREE *p =  current->left;
           //printf("instlist case:\n"); /* This code is suspect */
           while (p) {
-            print_tree(csound, "Top of loop\n", p);
+            if (PARSER_DEBUG) print_tree(csound, "Top of loop\n", p);
             if (p->left) {
               //print_tree(csound, "Left\n", p->left);
-              if (p->left->type == T_INTGR)
+              if (p->left->type == INTEGER_TOKEN) {
                 insert_instrtxt(csound, instrtxt, p->left->value->value);
+              }
+              else if (p->left->type == T_IDENT) {
+                int32  insno_priority = -1L;
+                char *c;
+                c = p->left->value->lexeme;
+
+                if (UNLIKELY(p->left->rate == (int) '+')) {
+                  insno_priority--;
+                }
+                if (UNLIKELY(!check_instr_name(c))) {
+                  synterr(csound, Str("invalid name for instrument"));
+                }
+                if (UNLIKELY(!named_instr_alloc(csound, c, instrtxt, insno_priority))) {
+                  synterr(csound, Str("instr %s redefined"), c);
+                }
+                instrtxt->insname = c;
+              }
             }
             else {
-              if (p->type == T_INTGR)
+              if (p->type == INTEGER_TOKEN) {
                 insert_instrtxt(csound, instrtxt, p->value->value);
+              }
+              else if (p->type == T_IDENT) {
+                int32  insno_priority = -1L;
+                char *c;
+                c = p->value->lexeme;
+
+                if (UNLIKELY(p->rate == (int) '+')) {
+                  insno_priority--;
+                }
+                if (UNLIKELY(!check_instr_name(c))) {
+                  synterr(csound, Str("invalid name for instrument"));
+                }
+                if (UNLIKELY(!named_instr_alloc(csound, c, instrtxt, insno_priority))) {
+                  synterr(csound, Str("instr %s redefined"), c);
+                }
+                instrtxt->insname = c;
+              }
               break;
             }
             p = p->right;
           }
         }
         break;
-      case T_UDO:
+      case UDO_TOKEN:
         /* csound->Message(csound, "UDO found\n"); */
 
         resetouts(csound); /* reset #out counts */
@@ -1110,7 +1129,7 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
         csound->Message(csound,
                         Str("Unknown TREE node of type %d found in root.\n"),
                         current->type);
-        /* if (PARSER_DEBUG) */ print_tree(csound, NULL, current);
+        if (PARSER_DEBUG) print_tree(csound, NULL, current);
       }
 
       current = current->next;
@@ -1160,20 +1179,20 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
     }
     /* That deals with missing values, however we do need ksmps to be integer */
     {
-      CSOUND    *p = (CSOUND*) csound;
       char      err_msg[128];
       sprintf(err_msg, "sr = %.7g, kr = %.7g, ksmps = %.7g\nerror:",
-                       p->tran_sr, p->tran_kr, p->tran_ksmps);
-      if (UNLIKELY(p->tran_sr <= FL(0.0)))
-        synterr(p, Str("%s invalid sample rate"), err_msg);
-      if (UNLIKELY(p->tran_kr <= FL(0.0)))
-        synterr(p, Str("%s invalid control rate"), err_msg);
-      else if (UNLIKELY(p->tran_ksmps < FL(0.75) ||
-                        FLOAT_COMPARE(p->tran_ksmps, MYFLT2LRND(p->tran_ksmps))))
-        synterr(p, Str("%s invalid ksmps value"), err_msg);
-      else if (UNLIKELY(FLOAT_COMPARE(p->tran_sr,
-                                      (double) p->tran_kr * p->tran_ksmps)))
-        synterr(p, Str("%s inconsistent sr, kr, ksmps"), err_msg);
+                       csound->tran_sr, csound->tran_kr, csound->tran_ksmps);
+      if (UNLIKELY(csound->tran_sr <= FL(0.0)))
+        synterr(csound, Str("%s invalid sample rate"), err_msg);
+      if (UNLIKELY(csound->tran_kr <= FL(0.0)))
+        synterr(csound, Str("%s invalid control rate"), err_msg);
+      else if (UNLIKELY(csound->tran_ksmps < FL(0.75) ||
+                        FLOAT_COMPARE(csound->tran_ksmps,
+                                      MYFLT2LRND(csound->tran_ksmps))))
+        synterr(csound, Str("%s invalid ksmps value"), err_msg);
+      else if (UNLIKELY(FLOAT_COMPARE(csound->tran_sr,
+                                      (double) csound->tran_kr * csound->tran_ksmps)))
+        synterr(csound, Str("%s inconsistent sr, kr, ksmps"), err_msg);
     }
 
     ip = csound->instxtanchor.nxtinstxt;
@@ -1183,10 +1202,12 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
       int thread, opnum = bp->t.opnum;
       if (opnum == ENDIN) break;
       if (opnum == LABEL) continue;
-      if (PARSER_DEBUG) printf("Instr 0 check on opcode=%s\n", bp->t.opcod);
+      if (PARSER_DEBUG)
+        csound->DebugMsg(csound, "Instr 0 check on opcode=%s\n", bp->t.opcod);
       if (UNLIKELY((thread = csound->opcodlst[opnum].thread) & 06 ||
                    (!thread && bp->t.pftype != 'b'))) {
-        printf("***opcode=%s thread=%d pftype=%c\n", bp->t.opcod, thread, bp->t.pftype);
+        csound->DebugMsg(csound, "***opcode=%s thread=%d pftype=%c\n",
+               bp->t.opcod, thread, bp->t.pftype);
         synterr(csound, Str("perf-pass statements illegal in header blk\n"));
       }
     }
@@ -1402,10 +1423,23 @@ static void insprep(CSOUND *csound, INSTRTXT *tp)
     mfree(csound, larg);
 }
 
+/* returns non-zero if 's' is defined in the global or local pool of names */
+
+static int lgexist2(CSOUND *csound, const char *s)
+{
+    unsigned char h = name_hash(csound, s);
+    NAME          *p = NULL;
+    for (p = ST(gblNames)[h]; p != NULL && sCmp(p->namep, s); p = p->nxt);
+    if (p != NULL)
+      return 1;
+    for (p = ST(lclNames)[h]; p != NULL && sCmp(p->namep, s); p = p->nxt);
+    return (p == NULL ? 0 : 1);
+}
+
 /* build pool of floating const values  */
 /* build lcl/gbl list of ds names, offsets */
 /* (no need to save the returned values) */
-static void lgbuild(CSOUND *csound, char *s)
+static void lgbuild(CSOUND *csound, char *s, int inarg)
 {
     char    c;
 
@@ -1416,7 +1450,7 @@ static void lgbuild(CSOUND *csound, char *s)
       constndx(csound, s);
     else if (c == '"')
       strconstndx(csound, s);
-    else if (!(lgexist(csound, s))) {
+    else if (!(lgexist2(csound, s)) && !inarg) {
       if (c == 'g' || (c == '#' && s[1] == 'g'))
         gblnamset(csound, s);
       else
@@ -1777,9 +1811,14 @@ static void convert_strconst_pool(CSOUND *csound, MYFLT *dst)
 #endif
 
 char argtyp2(CSOUND *csound, char *s)
-{                       /* find arg type:  d, w, a, k, i, c, p, r, S, B, b, t */
-    char c = *s;        /*   also set lgprevdef if !c && !p && !S */
+{                   /* find arg type:  d, w, a, k, i, c, p, r, S, B, b, t */
+    char c = *s;    /*   also set lgprevdef if !c && !p && !S */
 
+    /* VL: added this to make sure the object exists before we try to read
+       from it */
+    if (UNLIKELY(csound->otranGlobals == NULL)) {
+      csound->otranGlobals = csound->Calloc(csound, sizeof(OTRAN_GLOBALS));
+    }
     /* csound->Message(csound, "\nArgtyp2: received %s\n", s); */
 
     /*trap this before parsing for a number! */
@@ -1793,7 +1832,7 @@ char argtyp2(CSOUND *csound, char *s)
       return('p');                              /* pnum */
     if (c == '"')
       return('S');                              /* quoted String */
-      /* ST(lgprevdef) = lgexist(csound, s);  */             /* (lgprev) */
+     ST(lgprevdef) = lgexist2(csound, s);         /* (lgprev) */
     if (strcmp(s,"sr") == 0    || strcmp(s,"kr") == 0 ||
         strcmp(s,"0dbfs") == 0 || strcmp(s,"nchnls_i") == 0 ||
         strcmp(s,"ksmps") == 0 || strcmp(s,"nchnls") == 0)
@@ -1808,3 +1847,26 @@ char argtyp2(CSOUND *csound, char *s)
       return(c);
     else return('?');
 }
+
+/* For diagnostics map file name or macro name to an index */
+int file_to_int(CSOUND *csound, const char *name)
+{
+    extern char *strdup(const char *);
+    int n = 0;
+    char **filedir = csound->filedir;
+    while (filedir[n] && n<63) {        /* Do we have it already? */
+      if (strcmp(filedir[n], name)==0) return n; /* yes */
+      n++;                                       /* look again */
+    }
+    // Not there so add
+    // ensure long enough?
+    if (n==63) {
+      //csound->Die(csound, "Too many file/macros\n");
+      filedir[n] = strdup("**unknown**");
+    }
+    else {
+      filedir[n] = strdup(name);
+      filedir[n+1] = NULL;
+    }
+    return n;
+}
