@@ -1059,7 +1059,7 @@ TREE *csound_orc_expand_expressions(CSOUND * csound, TREE *root)
               break;
             }
             else if (anstype=='k' && argtype=='i') {
-              TREE* opTree = create_opcode_token(csound, "k.i");
+              TREE* opTree = create_opcode_token(csound, "=.k");
               opTree->right = make_leaf(csound, current->line, current->locn,
                                         T_IDENT_K, currentArg->left->value);
               opTree->left = current->left;
