@@ -30,7 +30,7 @@
 #include "midiops.h"
 #include "namedins.h"   /* IV - Oct 31 2002 */
 #include "pstream.h"
-extern MYFLT cpsocfrc[];        /* Needed by CPSOCTL */
+/*extern MYFLT cpsocfrc[]; */       /* Needed by CPSOCTL */
 
 static  void    showallocs(CSOUND *);
 static  void    deact(CSOUND *, INSDS *);
@@ -439,9 +439,28 @@ int MIDIinsert(CSOUND *csound, int insno, MCHNBLK *chn, MEVENT *mep)
       pfields[index] = value;
       if (UNLIKELY(O->msglevel & WARNMSG)) {
         csound->Message(csound, "  midiVelocityAmp: pfield: %3d  value: %3d\n",
-                        pfield, (int) pfields[index]);
+                        pfield, pfields[index]);
       }
     }
+    /*
+       the code above assumes &p1 is a pointer to an array of N pfields, but
+       this is wrong. It overwrites memory and uses it for passing p-field
+       values. When the overwritten memory is taken to be a pointer in the
+       loop below, the loop does not stop at the end of the opcode list
+       and causes iopadr to be garbage, leading to a segfault.
+       This happens where there is exactly one opcode in an instrument.
+       It is a nasty bug that needs to be fixed.
+
+       A possible solution is to  allocate always a minimum of 5 p-fields (see line
+       approx 1809 below). The extra p-fields appear to be hanging at the end of
+       an INSDS structure, and &p1 appears to be a legal array start address.
+       This allows p4 and p5 to be mapped, but no further p-fields (possibly).
+
+       This fix is a bit of hack IMHO. But I have implemented it here, as it
+       seemingly prevents the crashes.
+
+       (JPff) a safer fix to readthe extra arg numbers
+     */
 
     csound->curip = ip;
     csound->ids = (OPDS *)ip;
@@ -962,6 +981,9 @@ int useropcdset(CSOUND *csound, UOPCODE *p)
       /* initialise perf time address lists */
       buf->iobufp_ptrs[0] = buf->iobufp_ptrs[1] = NULL;
       buf->iobufp_ptrs[2] = buf->iobufp_ptrs[3] = NULL;
+      buf->iobufp_ptrs[4] = buf->iobufp_ptrs[5] = NULL;
+      buf->iobufp_ptrs[6] = buf->iobufp_ptrs[7] = NULL;
+
       /* store parameters of input and output channels, and parent ip */
       buf->uopcode_struct = (void*) p;
       buf->parent_ip = p->parent_ip = parent_ip;
@@ -1085,15 +1107,29 @@ int xinset(CSOUND *csound, XIN *p)
       *(tmp++) = *(p->args + *ndx_list);/* "to" address */
     }
     *(tmp++) = NULL;            /* put delimiter */
-    /* fsigs: we'll need to do extra work 
-    while (*++ndx_list >= 0) {
-      *(tmp++) = *(bufs + *ndx_list);   
-      *(tmp++) = *(p->args + *ndx_list);
+    /* fsigs: we'll need to do extra work */
+     while (*++ndx_list >= 0) {
+       void *in, *out;
+       in = (void *)*(bufs + *ndx_list);
+       *(tmp++) = (MYFLT *) in;
+       out = (void *) *(p->args + *ndx_list);
+       *(tmp++) = (MYFLT *) out;
+       memcpy(out, in, sizeof(PVSDAT));
     }
-    *(tmp++) = NULL;       */
+     *(tmp++) = NULL;
+    /* tsigs: similar to avove */
+     while (*++ndx_list >= 0) {
+       void *in, *out;
+       in = (void *)*(bufs + *ndx_list);
+       *(tmp++) = (MYFLT *) in;
+       out = (void *) *(p->args + *ndx_list);
+       *(tmp++) = (MYFLT *) out;
+       memcpy(out, in, sizeof(TABDAT));
+    }
+     *(tmp++) = NULL;
 
     /* fix for case when xout is omitted */
-    *(tmp++) = NULL; *tmp = NULL;
+    *(tmp++) = NULL;  *(tmp++) = NULL;  *(tmp++) = NULL; *tmp = NULL;
     return OK;
 }
 
@@ -1123,13 +1159,14 @@ int xoutset(CSOUND *csound, XOUT *p)
         *(dst++) = *(src++);
       *dst = '\0';
     }
-
-    /* skip input pointers, including the two delimiter NULLs */
+    /* skip input pointers, including the three delimiter NULLs */
     tmp = buf->iobufp_ptrs;
-    if (*tmp || *(tmp + 1)) tmp += (inm->perf_incnt << 1);
-    tmp += 2;
+    /* VL: needs to check if there are not 4 nulls in a sequence, which
+       would indicate no a, k, f or t sigs */
+    if (*tmp || *(tmp + 1) || *(tmp + 2) || *(tmp + 3)) tmp += (inm->perf_incnt << 1);
+    tmp += 4;  /* VL: this was 2, now 4 with fsigs and tsigs added */
     if (*tmp || *(tmp + 1))
-      return OK;
+    return OK;
 
     /* find a-rate variables and add to list of perf-time buf ptrs ... */
     while (*++ndx_list >= 0) {
@@ -1142,13 +1179,28 @@ int xoutset(CSOUND *csound, XOUT *p)
       *(tmp++) = *(p->args + *ndx_list);/* "from" address */
       *(tmp++) = *(bufs + *ndx_list);   /* "to" address */
     }
-    *tmp = NULL;                /* put delimiter */
-      /* fsigs: we'll need to do extra work 
+    *(tmp++) = NULL;                /* put delimiter */
+
+    /* fsigs: we'll need to do extra work */
     while (*++ndx_list >= 0) {
-      *(tmp++) = *(p->args + *ndx_list);
-      *(tmp++) = *(bufs + *ndx_list);   
+      void *in, *out;
+      in =  (void *) *(p->args + *ndx_list);
+      *(tmp++) = (MYFLT *) in;
+      out = (void *) *(bufs + *ndx_list);
+      *(tmp++) = (MYFLT *) out;
+      memcpy(out, in, sizeof(PVSDAT));
     }
-    *tmp = NULL; */
+    *(tmp++) = NULL;
+   /* tsigs: as above */
+    while (*++ndx_list >= 0) {
+      void *in, *out;
+      in =  (void *) *(p->args + *ndx_list);
+      *(tmp++) = (MYFLT *) in;
+      out = (void *) *(bufs + *ndx_list);
+      *(tmp++) = (MYFLT *) out;
+      memcpy(out, in, sizeof(TABDAT));
+    }
+    *tmp = NULL;
 
     return OK;
 }
@@ -1540,6 +1592,17 @@ int useropcd1(CSOUND *csound, UOPCODE *p)
         while (*(++tmp)) {              /* k-rate */
           ptr1 = *tmp; *(*(++tmp)) = *ptr1;
         }
+        /* VL: fsigs in need to be dealt with here */
+        while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(PVSDAT));
+         }
+        /* and tsigs */
+        while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(TABDAT));
+         }
+
         /*  run each opcode  */
         csound->pds = (OPDS *) (p->ip);
         while ((csound->pds = csound->pds->nxtp)) {
@@ -1566,6 +1629,16 @@ int useropcd1(CSOUND *csound, UOPCODE *p)
         while (*(++tmp)) {              /* k-rate */
           ptr1 = *tmp; *(*(++tmp)) = *ptr1;
         }
+        /* VL: fsigs in need to be dealt with here */
+        while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(PVSDAT));
+         }
+        /* and tsigs */
+        while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(TABDAT));
+         }
         /*  run each opcode  */
         csound->pds = (OPDS *) (p->ip);
         while ((csound->pds = csound->pds->nxtp)) {
@@ -1585,7 +1658,18 @@ int useropcd1(CSOUND *csound, UOPCODE *p)
     /* k-rate outputs are copied only in the last sub-kperiod, */
     /* so we do it now */
     while (*(++tmp)) {                  /* k-rate */
-      ptr1 = *tmp; *(*(++tmp)) = *ptr1;
+      ptr1 = *tmp;
+      *(*(++tmp)) = *ptr1;
+    }
+    /* VL: fsigs out need to be dealt with here */
+     while (*(++tmp)) {
+       ptr1 = *tmp;
+       memcpy((void *)(*(++tmp)), (void *)ptr1, sizeof(PVSDAT));
+    }
+     /* tsigs  */
+    while (*(++tmp)) {
+       ptr1 = *tmp;
+       memcpy((void *)(*(++tmp)), (void *)ptr1, sizeof(TABDAT));
     }
 
     /* restore globals */
@@ -1611,12 +1695,15 @@ int useropcd2(CSOUND *csound, UOPCODE *p)
     int     n;
     MYFLT   **tmp, *ptr1, *ptr2;
 
-    if (!(csound->pds = (OPDS*) (p->ip->nxtp))) goto endop; /* no perf code */
+     if (!(csound->pds = (OPDS*) (p->ip->nxtp))) goto endop; /* no perf code */
+
+    //csound->Message(csound, "end input\n"); /* FOR SOME REASON the opcode has no perf code */
     /* IV - Nov 16 2002: update release flag */
     p->ip->relesing = p->parent_ip->relesing;
 
     tmp = p->buf->iobufp_ptrs;
     if (csound->ksmps != 1) {           /* generic case for kr != sr */
+
       /* copy inputs */
       while (*tmp) {                    /* a-rate */
         ptr1 = *(tmp++); ptr2 = *(tmp++);
@@ -1625,9 +1712,23 @@ int useropcd2(CSOUND *csound, UOPCODE *p)
           *(ptr2++) = *(ptr1++);
         } while (--n);
       }
+
       while (*(++tmp)) {                /* k-rate */
         ptr1 = *tmp; *(*(++tmp)) = *ptr1;
       }
+
+      /* VL: fsigs in need to be dealt with here */
+       while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(PVSDAT));
+         }
+       /* VL: tsigs */
+        while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(TABDAT));
+         }
+
+
       /*  run each opcode  */
       do {
         (*csound->pds->opadr)(csound, csound->pds);
@@ -1644,11 +1745,22 @@ int useropcd2(CSOUND *csound, UOPCODE *p)
     else {                      /* special case for kr == sr */
       /* copy inputs */
       while (*tmp) {                    /* a-rate */
-        ptr1 = *(tmp++); *(*(tmp++)) = *ptr1;
+        ptr1 = *(tmp++);
+        *(*(tmp++)) = *ptr1;
       }
       while (*(++tmp)) {                /* k-rate */
         ptr1 = *tmp; *(*(++tmp)) = *ptr1;
       }
+      /* VL: fsigs in need to be dealt with here */
+       while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(PVSDAT));
+         }
+       /* VL: tsigs */
+       while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(TABDAT));
+         }
       /*  run each opcode  */
       do {
         (*csound->pds->opadr)(csound, csound->pds);
@@ -1661,6 +1773,16 @@ int useropcd2(CSOUND *csound, UOPCODE *p)
     while (*(++tmp)) {                  /* k-rate */
       ptr1 = *tmp; *(*(++tmp)) = *ptr1;
     }
+    /* VL: fsigs out need to be dealt with here */
+     while (*(++tmp)) {
+       ptr1 = *tmp;
+       memcpy((void *)(*(++tmp)), (void *)ptr1, sizeof(PVSDAT));
+       }
+     /* tsigs */
+    while (*(++tmp)) {
+       ptr1 = *tmp;
+       memcpy((void *)(*(++tmp)), (void *)ptr1, sizeof(TABDAT));
+       }
  endop:
     /* restore globals */
     csound->pds = saved_pds;
@@ -1682,16 +1804,27 @@ static void instance(CSOUND *csound, int insno)
     const OENTRY  *ep;
     LBLBLK    **lopdsp;
     LARGNO    *largp;
-    int       n, cnt, pextent, opnum;
+    int       n, cnt, pextent, opnum, pextra;
     char      *nxtopds, *opdslim;
     MYFLT     **argpp, *lclbas, *gbloffbas, *lcloffbas;
     int       *ndxp;
-    int       odebug = csound->oparms->odebug;
+    OPARMS    *O = csound->oparms;
+    int       odebug = O->odebug;
 
     lopdsp = csound->lopds;
     largp = (LARGNO*) csound->larg;
     tp = csound->instrtxtp[insno];
-    pextent = sizeof(INSDS) + tp->pextrab;      /* alloc new space,  */
+    /* VL: added 2 extra MYFLT pointers to the memory to account for possible
+       use by midi mapping flags */
+    n = 3;
+    if (O->midiKey>n) n = O->midiKey;
+    if (O->midiKeyCps>n) n = O->midiKeyCps;
+    if (O->midiKeyOct>n) n = O->midiKeyOct;
+    if (O->midiKeyPch>n) n = O->midiKeyPch;
+    if (O->midiVelocity>n) n = O->midiVelocity;
+    if (O->midiVelocityAmp>n) n = O->midiVelocityAmp;
+    pextra = n-3;
+    pextent = sizeof(INSDS) + tp->pextrab + pextra*sizeof(MYFLT *);      /* alloc new space,  */
     ip = (INSDS*) mcalloc(csound, (size_t) pextent + tp->localen + tp->opdstot);
     ip->csound = csound;
     ip->m_chnbp = (MCHNBLK*) NULL;
@@ -1768,7 +1901,8 @@ static void instance(CSOUND *csound, int insno)
       if ((n = ep->thread & 06) != 0) {         /* thread 2 OR 4:   */
         prvpds = prvpds->nxtp = opds;           /* link into pchain */
         if (!(n & 04) ||
-            (ttp->pftype == 'k' && ep->kopadr != NULL))
+            ((ttp->pftype == 'k' || ttp->pftype == 'c') &&
+             ep->kopadr != NULL))
           opds->opadr = ep->kopadr;             /*      krate or    */
         else opds->opadr = ep->aopadr;          /*      arate       */
         if (UNLIKELY(odebug))
@@ -1908,5 +2042,3 @@ int delete_instr(CSOUND *csound, DELETEIN *p)
       }
     return NOTOK;
 }
-
-
