@@ -7,6 +7,8 @@ typedef struct TREE {
   ORCTOKEN         *value;
   int           rate;
   int           len;
+  int           line;
+  int           locn;
   struct TREE   *left;
   struct TREE   *right;
   struct TREE   *next;
@@ -24,8 +26,8 @@ enum {
 #define PARSER_DEBUG (0)
 #endif
 
-TREE* make_node(CSOUND *, int, TREE*, TREE*);
-TREE* make_leaf(CSOUND *,int, ORCTOKEN*);
+TREE* make_node(CSOUND *, int, int, int, TREE*, TREE*);
+TREE* make_leaf(CSOUND *, int, int, int, ORCTOKEN*);
 ORCTOKEN* make_int(CSOUND *,char *);
 ORCTOKEN* make_num(CSOUND *,char *);
 ORCTOKEN *make_token(CSOUND *csound, char *s);
