@@ -547,7 +547,7 @@ static CS_NOINLINE int create_new_channel(CSOUND *csound, MYFLT **p,
     do {
       h = strhash_tabl_8[(unsigned char) *(s++) ^ h];
     } while (isalnum((unsigned char) *s) ||
-             *s == (char) '_' || *s == (char) '.');
+             *s == (char) '_' || *s == (char) '-' || *s == (char) '.');
     if (*s != (char) 0)
       return CSOUND_ERROR;
     /* create new empty database on first call */
@@ -942,10 +942,10 @@ static int chnset_opcode_perf_k(CSOUND *csound, CHNGET *p)
 
 static int chnset_opcode_perf_a(CSOUND *csound, CHNGET *p)
 {
-    int *lock = p->lock;        /* Need lock for the channel */
-    csoundSpinLock(lock);
+    /* Need lock for the channel */
+    csoundSpinLock(p->lock);
     memcpy(p->fp, p->arg, sizeof(MYFLT)*csound->ksmps);
-    csoundSpinUnLock(lock);
+    csoundSpinUnLock(p->lock);
     return OK;
 }
 
@@ -955,12 +955,12 @@ static int chnmix_opcode_perf(CSOUND *csound, CHNGET *p)
 {
     int   i = 0;
     int n = csound->ksmps;
-    int *lock = p->lock;        /* Need lock for the channel */
-    csoundSpinLock(lock);
+                                /* Need lock for the channel */
+    csoundSpinLock(p->lock);
     for (i=0; i<n; i++) {
       p->fp[i] += p->arg[i];
     }
-    csoundSpinUnLock(lock);
+    csoundSpinUnLock(p->lock);
     return OK;
 }
 
@@ -968,10 +968,10 @@ static int chnmix_opcode_perf(CSOUND *csound, CHNGET *p)
 
 static int chnclear_opcode_perf(CSOUND *csound, CHNCLEAR *p)
 {
-    int *lock = p->lock;        /* Need lock for the channel */
-    csoundSpinLock(lock);
+    /* Need lock for the channel */
+    csoundSpinLock(p->lock);
     memset(p->fp, 0, csound->ksmps*sizeof(MYFLT));
-    csoundSpinUnLock(lock);
+    csoundSpinUnLock(p->lock);
     return OK;
 }
 
@@ -1389,8 +1389,9 @@ int sensekey_perf(CSOUND *csound, KSENSE *p)
         retval = select(1, &rfds, NULL, NULL, &tv);
 
         if (retval) {
-          char    ch = (char) 0;
-          read(0, &ch, 1);
+          char    ch = '\0';
+          if (UNLIKELY(read(0, &ch, 1)!=1))
+            csound->Die(csound, "read failure in sensekey\n");
           keyCode = (int)((unsigned char) ch);
           /* FD_ISSET(0, &rfds) will be true. */
         }
