@@ -34,7 +34,7 @@ int ipow(CSOUND *csound, POW *p)        /*      Power for i-rate */
     MYFLT powerOf = *p->powerOf;
     if (UNLIKELY(in == FL(0.0) && powerOf == FL(0.0)))
       return csound->PerfError(csound, Str("NaN in pow\n"));
-    else if (p->norm!=NULL)
+    else if (p->norm!=NULL && *p->norm != FL(0.0))
       *p->sr = POWER(in, powerOf) / *p->norm;
     else
       *p->sr = POWER(in, powerOf);
@@ -266,12 +266,13 @@ static MYFLT poissrand(CSOUND *csound, MYFLT lambda)
 
 int auniform(CSOUND *csound, PRAND *p)  /* Uniform distribution */
 {
-    MYFLT   *out = p->out, *endp = p->out + csound->ksmps;
+    MYFLT   *out = p->out;
+    int n, nsmps = csound->ksmps;
     double  scale = (double)*p->arg1 * (1.0 / 4294967295.03125);
 
-    do {
-      *(out++) = (MYFLT)((double)csoundRandMT(&(csound->randState_)) * scale);
-    } while (out < endp);
+    for (n=0; n<nsmps; n++) {
+      out[n] = (MYFLT)((double)csoundRandMT(&(csound->randState_)) * scale);
+    }
     return OK;
 }
 
@@ -326,12 +327,6 @@ int exprndiset(CSOUND *csound, PRANDI *p)
     return OK;
 }
 
-int iexprndi(CSOUND *csound, PRANDI *p)
-{
-    exprndiset(csound, p);
-    return kexprndi(csound, p);
-}
-
 int kexprndi(CSOUND *csound, PRANDI *p)
 {                                       /* rslt = (num1 + diff*phs) * amp */
     /* IV - Jul 11 2002 */
@@ -340,12 +335,18 @@ int kexprndi(CSOUND *csound, PRANDI *p)
     if (UNLIKELY(p->phs >= MAXLEN)) {         /* when phs overflows,  */
       p->phs &= PHMASK;                       /*      mod the phs     */
       p->num1 = p->num2;                      /*      & new num vals  */
-      p->num2 = exprand(csound, *p->arg1); 
+      p->num2 = exprand(csound, *p->arg1);
       p->dfdmax = (p->num2 - p->num1) / FMAXLEN;
     }
     return OK;
 }
 
+int iexprndi(CSOUND *csound, PRANDI *p)
+{
+    exprndiset(csound, p);
+    return kexprndi(csound, p);
+}
+
 int aexprndi(CSOUND *csound, PRANDI *p)
 {
     int32       phs = p->phs, inc;
@@ -448,12 +449,6 @@ int gaussiset(CSOUND *csound, PRANDI *p)
     return OK;
 }
 
-int igaussi(CSOUND *csound, PRANDI *p)
-{
-    gaussiset(csound, p);
-    return kgaussi(csound, p);
-}
-
 int kgaussi(CSOUND *csound, PRANDI *p)
 {                                       /* rslt = (num1 + diff*phs) * amp */
     /* IV - Jul 11 2002 */
@@ -462,12 +457,18 @@ int kgaussi(CSOUND *csound, PRANDI *p)
     if (UNLIKELY(p->phs >= MAXLEN)) {           /* when phs overflows,  */
       p->phs &= PHMASK;                         /*      mod the phs     */
       p->num1 = p->num2;                        /*      & new num vals  */
-      p->num2 = gaussrand(csound, *p->arg1); 
+      p->num2 = gaussrand(csound, *p->arg1);
       p->dfdmax = (p->num2 - p->num1) / FMAXLEN;
     }
     return OK;
 }
 
+int igaussi(CSOUND *csound, PRANDI *p)
+{
+    gaussiset(csound, p);
+    return kgaussi(csound, p);
+}
+
 int agaussi(CSOUND *csound, PRANDI *p)
 {
     int32       phs = p->phs, inc;
@@ -531,12 +532,6 @@ int cauchyiset(CSOUND *csound, PRANDI *p)
     return OK;
 }
 
-int icauchyi(CSOUND *csound, PRANDI *p)
-{
-    cauchyiset(csound, p);
-    return kcauchyi(csound, p);
-}
-
 int kcauchyi(CSOUND *csound, PRANDI *p)
 {                                       /* rslt = (num1 + diff*phs) * amp */
     /* IV - Jul 11 2002 */
@@ -545,12 +540,18 @@ int kcauchyi(CSOUND *csound, PRANDI *p)
     if (UNLIKELY(p->phs >= MAXLEN)) {         /* when phs overflows,  */
       p->phs &= PHMASK;                       /*      mod the phs     */
       p->num1 = p->num2;                      /*      & new num vals  */
-      p->num2 = cauchrand(csound, *p->arg1); 
+      p->num2 = cauchrand(csound, *p->arg1);
       p->dfdmax = (p->num2 - p->num1) / FMAXLEN;
     }
     return OK;
 }
 
+int icauchyi(CSOUND *csound, PRANDI *p)
+{
+    cauchyiset(csound, p);
+    return kcauchyi(csound, p);
+}
+
 int acauchyi(CSOUND *csound, PRANDI *p)
 {
     int32       phs = p->phs, inc;
@@ -705,4 +706,3 @@ int gen21_rand(FGDATA *ff, FUNC *ftp)
     }
     return OK;
 }
-
