@@ -228,12 +228,14 @@ int diskin2_init(CSOUND *csound, DISKIN2 *p)
     p->fdch.fd = fd;
     fdrecord(csound, &(p->fdch));
     /* print file information */
-    csound->Message(csound, Str("diskin2: opened '%s':\n"
-                                "         %d Hz, %d channel(s), "
-                                "%ld sample frames\n"),
-                    csound->GetFileName(fd),
-                    (int)sfinfo.samplerate, (int)sfinfo.channels,
-                    (int32) sfinfo.frames);
+    if (UNLIKELY((csound->oparms_.msglevel & 7) == 7)) {
+      csound->Message(csound, Str("diskin2: opened '%s':\n"
+                                  "         %d Hz, %d channel(s), "
+                                  "%ld sample frames\n"),
+                      csound->GetFileName(fd),
+                      (int)sfinfo.samplerate, (int)sfinfo.channels,
+                      (int32) sfinfo.frames);
+    }
     /* check number of channels in file (must equal the number of outargs) */
     if (UNLIKELY(sfinfo.channels != p->nChannels)) {
       return csound->InitError(csound,
@@ -327,7 +329,8 @@ int diskin2_perf(CSOUND *csound, DISKIN2 *p)
     int32   ndx;
     int     i, nn, chn, wsized2, warp;
 
-    if (UNLIKELY(p->fdch.fd == NULL)) {
+    if (UNLIKELY(p->fdch.fd == NULL) ) goto file_error;
+    if(!p->initDone && !p->iSkipInit){
       return csound->PerfError(csound, Str("diskin2: not initialised"));
     }
     if (*(p->kTranspose) != p->prv_kTranspose) {
@@ -492,6 +495,9 @@ int diskin2_perf(CSOUND *csound, DISKIN2 *p)
       for (nn = 0; nn < csound->ksmps; nn++)
         p->aOut[chn][nn] *= csound->e0dbfs;
     return OK;
+ file_error:
+    csound->ErrorMsg(csound, "diskin2: file descriptor closed or invalid\n");
+   return NOTOK;
 }
 
 /* -------- soundin opcode: simplified version of diskin2 -------- */
