@@ -110,7 +110,7 @@ int gbzset(CSOUND *csound, GBUZZ *p)
     return NOTOK;
 }
 
-inline MYFLT intpow1(MYFLT x, int32 n)   /* Binary positive power function */
+static inline MYFLT intpow1(MYFLT x, int32 n)   /* Binary positive power function */
 {
     MYFLT ans = FL(1.0);
     while (n!=0) {
@@ -448,7 +448,7 @@ int rndset(CSOUND *csound, RAND *p)
       if (*p->iseed > FL(1.0)) {    /* As manual suggest seed in range [0,1] */
         uint32 seed;         /* I reinterpret >1 as a time seed */
         seed = csound->GetRandomSeedFromTime();
-        csound->Message(csound, Str("Seeding from current time %lu\n"), seed);
+        csound->Warning(csound, Str("Seeding from current time %lu\n"), seed);
         if (!p->new) {
           p->rand = (int32) (seed & 0xFFFFUL);
         }
@@ -548,7 +548,7 @@ int rhset(CSOUND *csound, RANDH *p)
       if (*p->iseed > FL(1.0)) {    /* As manual suggest sseed in range [0,1] */
         uint32 seed;         /* I reinterpret >1 as a time seed */
         seed = csound->GetRandomSeedFromTime();
-        csound->Message(csound, Str("Seeding from current time %lu\n"), seed);
+        csound->Warning(csound, Str("Seeding from current time %lu\n"), seed);
         if (!p->new) {
           p->rand = (int32) (seed & 0xFFFFUL);
           p->num1 = (MYFLT) ((int16) p->rand) * DV32768;
@@ -646,7 +646,7 @@ int riset(CSOUND *csound, RANDI *p)
       if (*p->iseed > FL(1.0)) { /* As manual suggest sseed in range [0,1] */
         uint32 seed;             /* I reinterpret >1 as a time seed */
         seed = csound->GetRandomSeedFromTime();
-        csound->Message(csound, Str("Seeding from current time %lu\n"), seed);
+        csound->Warning(csound, Str("Seeding from current time %lu\n"), seed);
         if (!p->new) {
           int16 rand = (int16)seed;
 /*           int16 ss = rand; */
