@@ -123,9 +123,11 @@ input  |    |------>|
                     Move static fn declarations out of function
  */
 
-#include "csdl.h"
+//#include "csdl.h"
+#include "csoundCore.h"
 #include "babo.h"
 #include <math.h>
+#include "interlocks.h"
 
 #if !defined(FLT_MAX)
 #define FLT_MAX         (1.0e38)
@@ -153,7 +155,7 @@ BaboMemory_create(CSOUND *csound, BaboMemory *this, size_t size_in_floats)
 
     csound->AuxAlloc(csound, size_in_bytes, &this->memptr);
 
-    memset(this->memptr.auxp, 0, size_in_bytes);
+    //memset(this->memptr.auxp, 0, size_in_bytes);
 
     this->samples = size_in_floats;
 
@@ -818,9 +820,9 @@ babo(CSOUND *csound, void *entry)
 
 #define S(x)    sizeof(x)
 
-static OENTRY localops[] = {
-{ "babo",   S(BABO), 5, "aa", "akkkiiijj",(SUBR)baboset, NULL, (SUBR)babo   }
+static OENTRY babo_localops[] = {
+  { "babo",   S(BABO), TR|5, "aa", "akkkiiijj",(SUBR)baboset, NULL, (SUBR)babo   },
 };
 
-LINKAGE
+LINKAGE1(babo_localops)
 
