@@ -40,7 +40,7 @@ static int datemyfltset(CSOUND *csound, DATEMYFLT *p)
 #ifdef USE_DOUBLE
     const time_t base = 0;
 #else
-    /*    time_t base = 946684800;    /* 1 Jan 2000 */
+    /*    time_t base = 946684800; */  /* 1 Jan 2000 */
     const time_t base = 1262304000;    /* 1 Jan 2010 */
 #endif
     *p->time_ = (MYFLT) (time(NULL)-base);
@@ -73,11 +73,11 @@ static int datestringset(CSOUND *csound, DATESTRING *p)
     return OK;
 }
 
-static OENTRY localops[] =
+static OENTRY date_localops[] =
 {
     { "date",    sizeof(DATEMYFLT),     1,     "i",    "",(SUBR)datemyfltset, NULL, NULL },
     { "dates",   sizeof(DATESTRING),    1,     "S",    "j",(SUBR)datestringset, NULL, NULL },
 };
 
-LINKAGE
+LINKAGE1(date_localops)
 
