@@ -84,7 +84,7 @@ static Image * __doOpenImage(char * filename, CSOUND *csound)
     unsigned char header[8];
     png_structp png_ptr;
     png_infop info_ptr;
-    png_infop end_ptr;
+    /* png_infop end_ptr; */
     int is_png;
     png_uint_32 width, height, rowbytes;
     int bit_depth;
@@ -103,7 +103,10 @@ static Image * __doOpenImage(char * filename, CSOUND *csound)
       return NULL;
     }
 
-    fread(header, 1, hs, fp);
+    if (UNLIKELY(hs!=fread(header, 1, hs, fp)))
+      csound->InitError(csound,
+                        Str("imageload: file %s is not in PNG format.\n"),
+                        filename);
     is_png = !png_sig_cmp(header, 0, hs);
 
     if (UNLIKELY(!is_png)) {
@@ -128,13 +131,13 @@ static Image * __doOpenImage(char * filename, CSOUND *csound)
       return NULL;
     }
 
-    end_ptr = png_create_info_struct(png_ptr);
-    if (UNLIKELY(!end_ptr)) {
-      png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp) NULL);
-      csound->InitError(csound, Str("imageload: out of memory.\n"));
-      csound->FileClose(csound, fd);
-      return NULL;
-    }
+    /* end_ptr = png_create_info_struct(png_ptr); */
+    /* if (UNLIKELY(!end_ptr)) { */
+    /*   png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp) NULL); */
+    /*   csound->InitError(csound, Str("imageload: out of memory.\n")); */
+    /*   csound->FileClose(csound, fd); */
+    /*   return NULL; */
+    /* } */
 
     png_init_io(png_ptr, fp);
     png_set_sig_bytes(png_ptr, hs);
@@ -612,7 +615,7 @@ static int imagefree (CSOUND *csound, IMGSAVE * p)
 
 #define S(x)    sizeof(x)
 
-static OENTRY localops[] = {
+static OENTRY image_localops[] = {
   { "imageload",  S(IMGLOAD),  1, "i", "S",   (SUBR)imageload, NULL, NULL   },
   { "imagecreate",S(IMGCREATE),1, "i", "ii",  (SUBR)imagecreate, NULL, NULL },
   { "imagesize",  S(IMGSIZE),  1, "ii", "i",  (SUBR)imagesize, NULL, NULL   },
@@ -622,8 +625,8 @@ static OENTRY localops[] = {
     (SUBR)imagesetpixel, (SUBR)imagesetpixel, (SUBR)imagesetpixel_a   },
   { "imagesave",  S(IMGSAVE),  1, "", "iS",   (SUBR)imagesave, NULL, NULL   },
   { "imagefree",  S(IMGFREE),  1, "", "i",    (SUBR)imagefree, NULL, NULL   },
-
 };
 
 
-LINKAGE
+LINKAGE1(image_localops)
+
