@@ -45,7 +45,9 @@
 /*  Sandpapr (sandpaper)                                  */
 /**********************************************************/
 
-#include "csdl.h"
+// #include "csdl.h"
+#include "csoundCore.h"
+#include "interlocks.h"
 #include "phisem.h"
 #include <math.h>
 
@@ -900,7 +902,7 @@ static int wuterset(CSOUND *csound, WUTER *p)
 
     p->sndLevel = FL(0.0);
     p->kloop = (int)(p->h.insdshead->offtim * csound->ekr)
-		      - (int)(csound->ekr * *p->dettack);
+             - (int)(csound->ekr * *p->dettack);
 
     p->outputs00       = FL(0.0);
     p->outputs01       = FL(0.0);
@@ -1231,7 +1233,7 @@ static int sleighbells(CSOUND *csound, SLEIGHBELLS *p)
 
 #define S(x)    sizeof(x)
 
-static OENTRY localops[] = {
+static OENTRY phisem_localops[] = {
 { "cabasa",  S(CABASA),  5, "a", "iiooo",    (SUBR)cabasaset, NULL, (SUBR)cabasa},
 { "crunch",  S(CABASA),  5, "a", "iiooo",    (SUBR)crunchset, NULL, (SUBR)cabasa},
 { "sekere",  S(SEKERE),  5, "a", "iiooo",    (SUBR)sekereset, NULL, (SUBR)sekere},
@@ -1246,5 +1248,4 @@ static OENTRY localops[] = {
                                        (SUBR)sleighset, NULL, (SUBR)sleighbells }
 };
 
-LINKAGE
-
+LINKAGE1(phisem_localops)
