@@ -50,7 +50,6 @@ static int pvscent(CSOUND *csound, PVSCENT *p)
     MYFLT c = FL(0.0);
     MYFLT d = FL(0.0);
     MYFLT j, binsize = FL(0.5)*csound->esr/(MYFLT)N;
-#ifndef OLPC
     if (p->fin->sliding) {
       CMPLX *fin = (CMPLX*) p->fin->frame.auxp;
       int NB = p->fin->NB;
@@ -60,7 +59,6 @@ static int pvscent(CSOUND *csound, PVSCENT *p)
       }
     }
     else
-#endif
       {
         float *fin = (float *) p->fin->frame.auxp;
         if (p->lastframe < p->fin->framecount) {
@@ -75,7 +73,6 @@ static int pvscent(CSOUND *csound, PVSCENT *p)
     return OK;
 }
 
-#ifndef OLPC
 static int pvsscent(CSOUND *csound, PVSCENT *p)
 {
     MYFLT *a = p->ans;
@@ -121,7 +118,6 @@ static int pvsscent(CSOUND *csound, PVSCENT *p)
     }
     return OK;
 }
-#endif
 
 /* PVSPITCH opcode by Ala OCinneide */
 
@@ -161,14 +157,16 @@ typedef struct _pvspitch
 int pvspitch_init(CSOUND *csound, PVSPITCH *p)
 {
     /* Initialise frame count to zero. */
+    int size;
     p->lastframe = 0;
 
-#ifndef OLPC
     if (UNLIKELY(p->fin->sliding))
       return csound->InitError(csound, Str("SDFT case not implemented yet"));
-#endif
-    csound->AuxAlloc(csound, sizeof(MYFLT)*(p->fin->N+2)/4, &p->peakfreq);
-    csound->AuxAlloc(csound, sizeof(MYFLT)*(p->fin->N+2)/4, &p->inharmonic);
+    size = sizeof(MYFLT)*(p->fin->N+2);
+    if (p->peakfreq.auxp == NULL || p->peakfreq.size < size)
+    csound->AuxAlloc(csound, size, &p->peakfreq);
+    if (p->inharmonic.auxp == NULL || p->inharmonic.size < size)
+    csound->AuxAlloc(csound, size, &p->inharmonic);
     if (UNLIKELY(p->fin->format!=PVS_AMP_FREQ)) {
       return csound->InitError(csound,
                                "PV Frames must be in AMP_FREQ format!\n");
@@ -231,7 +229,7 @@ int pvspitch_process(CSOUND *csound, PVSPITCH *p)
         maxPartial = (int) (PeakFreq[0]/lowHearThreshold);
 
         /* Calculates the inharmonicity for each fundamental candidate */
-        for (i=0; i<maxPartial; i++) {
+        for (i=0; i<maxPartial && i < numBins/2; i++) {
           inharmonic[i] = FL(0.0);
           f0Cand = PeakFreq[0]/(i+1);
 
@@ -298,11 +296,7 @@ int pvspitch_process(CSOUND *csound, PVSPITCH *p)
 }
 
 static OENTRY localops[] = {
-#ifdef OLPC
-  { "pvscent", sizeof(PVSCENT), 3, "k", "f", (SUBR)pvscentset, (SUBR)pvscent, NULL},
-#else
   { "pvscent", sizeof(PVSCENT), 3, "s", "f", (SUBR)pvscentset, (SUBR)pvscent, (SUBR)pvsscent },
-#endif
   { "pvspitch", sizeof(PVSPITCH), 3, "kk", "fk",
                            (SUBR)pvspitch_init, (SUBR)pvspitch_process, NULL}
 };
