@@ -45,10 +45,8 @@ static int pvsdemix_init(CSOUND *csound, PVSDEMIX *p)
     int M;
     p->beta = (int)(*p->slices);
 
-#ifndef OLPC
     if (UNLIKELY(p->finleft->sliding))
       return csound->InitError(csound, Str("SDFT case not implemented yet"));
-#endif
    M = (N+2)*sizeof(float);
     if (p->fout->frame.auxp==NULL || p->fout->frame.size<M)
       csound->AuxAlloc(csound, M,&p->fout->frame);
