@@ -115,6 +115,14 @@ public:
   MYFLT *kvalue2;
   MYFLT *kcontroller3;
   MYFLT *kvalue3;
+  MYFLT *kcontroller4;
+  MYFLT *kvalue4;
+  MYFLT *kcontroller5;
+  MYFLT *kvalue5;
+  MYFLT *kcontroller6;
+  MYFLT *kvalue6;
+  MYFLT *kcontroller7;
+  MYFLT *kvalue7;
   // State.
   T *instrument;
   size_t ksmps;
@@ -127,6 +135,14 @@ public:
   MYFLT oldkvalue2;
   MYFLT oldkcontroller3;
   MYFLT oldkvalue3;
+  MYFLT oldkcontroller4;
+  MYFLT oldkvalue4;
+  MYFLT oldkcontroller5;
+  MYFLT oldkvalue5;
+  MYFLT oldkcontroller6;
+  MYFLT oldkvalue6;
+  MYFLT oldkcontroller7;
+  MYFLT oldkvalue7;
   STKInstrumentAdapter() : instrument(0) {}
   int init(CSOUND *csound)
   {
@@ -147,6 +163,14 @@ public:
       oldkvalue2 = -1.0;
       oldkcontroller3 = -1.0;
       oldkvalue3 = -1.0;
+      oldkcontroller4 = -1.0;
+      oldkvalue4 = -1.0;
+      oldkcontroller5 = -1.0;
+      oldkvalue5 = -1.0;
+      oldkcontroller6 = -1.0;
+      oldkvalue6 = -1.0;
+      oldkcontroller7 = -1.0;
+      oldkvalue7 = -1.0;
       return OK;
   }
   int kontrol(CSOUND *csound)
@@ -177,6 +201,30 @@ public:
               oldkcontroller3 = *kcontroller3;
               oldkvalue3 = *kvalue3;
             }
+          if(*kcontroller4 != oldkcontroller4 || *kvalue4 != oldkvalue4)
+            {
+              instrument->controlChange(static_cast<int>(*kcontroller4), *kvalue4);
+              oldkcontroller4 = *kcontroller4;
+              oldkvalue4 = *kvalue4;
+            }
+          if(*kcontroller5 != oldkcontroller5 || *kvalue5 != oldkvalue5)
+            {
+              instrument->controlChange(static_cast<int>(*kcontroller5), *kvalue5);
+              oldkcontroller5 = *kcontroller5;
+              oldkvalue5 = *kvalue5;
+            }
+          if(*kcontroller6 != oldkcontroller6 || *kvalue6 != oldkvalue6)
+            {
+              instrument->controlChange(static_cast<int>(*kcontroller6), *kvalue6);
+              oldkcontroller6 = *kcontroller6;
+              oldkvalue6 = *kvalue6;
+            }
+          if(*kcontroller7 != oldkcontroller7 || *kvalue7 != oldkvalue7)
+            {
+              instrument->controlChange(static_cast<int>(*kcontroller7), *kvalue7);
+              oldkcontroller7 = *kcontroller7;
+              oldkvalue7 = *kvalue7;
+            }
           for(size_t i = 0; i < ksmps; i++)
             {
               aoutput[i] = instrument->tick();
@@ -211,6 +259,14 @@ public:
   MYFLT *kvalue2;
   MYFLT *kcontroller3;
   MYFLT *kvalue3;
+  MYFLT *kcontroller4;
+  MYFLT *kvalue4;
+  MYFLT *kcontroller5;
+  MYFLT *kvalue5;
+  MYFLT *kcontroller6;
+  MYFLT *kvalue6;
+  MYFLT *kcontroller7;
+  MYFLT *kvalue7;
   // State.
   T *instrument;
   size_t ksmps;
@@ -223,6 +279,14 @@ public:
   MYFLT oldkvalue2;
   MYFLT oldkcontroller3;
   MYFLT oldkvalue3;
+  MYFLT oldkcontroller4;
+  MYFLT oldkvalue4;
+  MYFLT oldkcontroller5;
+  MYFLT oldkvalue5;
+  MYFLT oldkcontroller6;
+  MYFLT oldkvalue6;
+  MYFLT oldkcontroller7;
+  MYFLT oldkvalue7;
   STKInstrumentAdapter1() : instrument(0) {}
   int init(CSOUND *csound)
   {
@@ -242,6 +306,14 @@ public:
       oldkvalue2 = -1.0;
       oldkcontroller3 = -1.0;
       oldkvalue3 = -1.0;
+      oldkcontroller4 = -1.0;
+      oldkvalue4 = -1.0;
+      oldkcontroller5 = -1.0;
+      oldkvalue5 = -1.0;
+      oldkcontroller6 = -1.0;
+      oldkvalue6 = -1.0;
+      oldkcontroller7 = -1.0;
+      oldkvalue7 = -1.0;
       return OK;
   }
   int kontrol(CSOUND *csound)
@@ -272,6 +344,30 @@ public:
               oldkcontroller3 = *kcontroller3;
               oldkvalue3 = *kvalue3;
             }
+          if(*kcontroller4 != oldkcontroller4 || *kvalue4 != oldkvalue4)
+            {
+              instrument->controlChange(static_cast<int>(*kcontroller4), *kvalue4);
+              oldkcontroller4 = *kcontroller4;
+              oldkvalue4 = *kvalue4;
+            }
+          if(*kcontroller5 != oldkcontroller5 || *kvalue5 != oldkvalue5)
+            {
+              instrument->controlChange(static_cast<int>(*kcontroller5), *kvalue5);
+              oldkcontroller5 = *kcontroller5;
+              oldkvalue5 = *kvalue5;
+            }
+          if(*kcontroller6 != oldkcontroller6 || *kvalue6 != oldkvalue6)
+            {
+              instrument->controlChange(static_cast<int>(*kcontroller6), *kvalue6);
+              oldkcontroller6 = *kcontroller6;
+              oldkvalue6 = *kvalue6;
+            }
+          if(*kcontroller7 != oldkcontroller7 || *kvalue7 != oldkvalue7)
+            {
+              instrument->controlChange(static_cast<int>(*kcontroller7), *kvalue7);
+              oldkcontroller7 = *kcontroller7;
+              oldkvalue7 = *kvalue7;
+            }
           for(size_t i = 0; i < ksmps; i++)
             {
               aoutput[i] = instrument->tick();
@@ -296,272 +392,272 @@ extern "C"
       {
         (char*)"STKBandedWG",
         sizeof(STKInstrumentAdapter<BandedWG>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<BandedWG>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<BandedWG>::kontrol_,
+        0,
       },
       {
         (char*)"STKBeeThree",
         sizeof(STKInstrumentAdapter<BeeThree>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<BeeThree>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<BeeThree>::kontrol_,
+        0,
       },
       {
         (char*)"STKBlowBotl",
         sizeof(STKInstrumentAdapter<BlowBotl>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<BlowBotl>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<BlowBotl>::kontrol_,
+        0,
       },
       {
         (char*)"STKBlowHole",
         sizeof(STKInstrumentAdapter1<BlowHole>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter1<BlowHole>::init_,
-        0,
         (SUBR) STKInstrumentAdapter1<BlowHole>::kontrol_,
+        0,
       },
       {
         (char*)"STKBowed",
         sizeof(STKInstrumentAdapter1<Bowed>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter1<Bowed>::init_,
-        0,
         (SUBR) STKInstrumentAdapter1<Bowed>::kontrol_,
+        0,
       },
       {
         (char*)"STKBrass",
         sizeof(STKInstrumentAdapter1<Brass>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter1<Brass>::init_,
-        0,
         (SUBR) STKInstrumentAdapter1<Brass>::kontrol_,
+        0,
       },
       {
         (char*)"STKClarinet",
         sizeof(STKInstrumentAdapter1<Clarinet>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter1<Clarinet>::init_,
-        0,
         (SUBR) STKInstrumentAdapter1<Clarinet>::kontrol_,
+        0,
       },
       {
         (char*)"STKDrummer",
         sizeof(STKInstrumentAdapter<Drummer>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<Drummer>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<Drummer>::kontrol_,
+        0,
       },
       {
         (char*)"STKFlute",
         sizeof(STKInstrumentAdapter1<Flute>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter1<Flute>::init_,
-        0,
         (SUBR) STKInstrumentAdapter1<Flute>::kontrol_,
+        0,
       },
       {
         (char*)"STKFMVoices",
         sizeof(STKInstrumentAdapter<FMVoices>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<FMVoices>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<FMVoices>::kontrol_,
+        0,
       },
       {
         (char*)"STKHevyMetl",
         sizeof(STKInstrumentAdapter<HevyMetl>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<HevyMetl>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<HevyMetl>::kontrol_,
+        0,
       },
       {
         (char*)"STKMandolin",
         sizeof(STKInstrumentAdapter1<Mandolin>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter1<Mandolin>::init_,
-        0,
         (SUBR) STKInstrumentAdapter1<Mandolin>::kontrol_,
+        0,
       },
       {
         (char*)"STKModalBar",
         sizeof(STKInstrumentAdapter<ModalBar>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<ModalBar>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<ModalBar>::kontrol_,
+        0,
       },
       {
         (char*)"STKMoog",
         sizeof(STKInstrumentAdapter<Moog>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<Moog>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<Moog>::kontrol_,
+        0,
       },
       {
         (char*)"STKPercFlut",
         sizeof(STKInstrumentAdapter<PercFlut>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<PercFlut>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<PercFlut>::kontrol_,
+        0,
       },
       {
         (char*)"STKPlucked",
         sizeof(STKInstrumentAdapter1<Plucked>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter1<Plucked>::init_,
-        0,
         (SUBR) STKInstrumentAdapter1<Plucked>::kontrol_,
+        0,
       },
       {
         (char*)"STKResonate",
         sizeof(STKInstrumentAdapter<Resonate>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<Resonate>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<Resonate>::kontrol_,
+        0,
       },
       {
         (char*)"STKRhodey",
         sizeof(STKInstrumentAdapter<Rhodey>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<Rhodey>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<Rhodey>::kontrol_,
+        0,
       },
       {
         (char*)"STKSaxofony",
         sizeof(STKInstrumentAdapter1<Saxofony>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter1<Saxofony>::init_,
-        0,
         (SUBR) STKInstrumentAdapter1<Saxofony>::kontrol_,
+        0,
       },
       {
         (char*)"STKShakers",
         sizeof(STKInstrumentAdapter<Shakers>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<Shakers>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<Shakers>::kontrol_,
+        0,
       },
       {
         (char*)"STKSimple",
         sizeof(STKInstrumentAdapter<Simple>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<Simple>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<Simple>::kontrol_,
+        0,
       },
       {
         (char*)"STKSitar",
         sizeof(STKInstrumentAdapter<Sitar>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<Sitar>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<Sitar>::kontrol_,
+        0,
       },
       {
         (char*)"STKStifKarp",
         sizeof(STKInstrumentAdapter1<StifKarp>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter1<StifKarp>::init_,
-        0,
         (SUBR) STKInstrumentAdapter1<StifKarp>::kontrol_,
+        0,
       },
       {
         (char*)"STKTubeBell",
         sizeof(STKInstrumentAdapter<TubeBell>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<TubeBell>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<TubeBell>::kontrol_,
+        0,
       },
       {
         (char*)"STKVoicForm",
         sizeof(STKInstrumentAdapter<VoicForm>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<VoicForm>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<VoicForm>::kontrol_,
+        0,
       },
       {
         (char*)"STKWhistle",
         sizeof(STKInstrumentAdapter<Whistle>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<Whistle>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<Whistle>::kontrol_,
+        0,
       },
       {
         (char*)"STKWurley",
         sizeof(STKInstrumentAdapter<Wurley>),
-        5,
+        3,
         (char*)"a",
-        (char*)"iijjjjjjjj",
+        (char*)"iiJJJJJJJJJJJJJJJJ",
         (SUBR) STKInstrumentAdapter<Wurley>::init_,
-        0,
         (SUBR) STKInstrumentAdapter<Wurley>::kontrol_,
+        0,
       },
       {
         0,
@@ -596,7 +692,7 @@ extern "C"
         Stk::setRawwavePath(path);
         csound_global_mutex_unlock();
         csound->Message(csound,
-			Str("RAWWAVE_PATH: %s\n"), Stk::rawwavePath().c_str());
+                        Str("RAWWAVE_PATH: %s\n"), Stk::rawwavePath().c_str());
       }
     int status = 0;
     for(OENTRY *oentry = &oentries[0]; oentry->opname; oentry++)
