@@ -33,10 +33,6 @@
 #include "csoundCore.h"
 #include "csGblMtx.h"
 
-static CS_NOINLINE void notImplementedWarning_(const char *name)
-{
-    fprintf(stderr, Str("%s() is not implemented on this platform.\n"), name);
-}
 
 #if defined(WIN32)
 #include <windows.h>
@@ -91,6 +87,11 @@ PUBLIC void csoundSleep(size_t milliseconds)
 
 #elif defined(mac_classic)
 
+static CS_NOINLINE void notImplementedWarning_(const char *name)
+{
+    fprintf(stderr, Str("%s() is not implemented on this platform.\n"), name);
+}
+
 PUBLIC long csoundRunCommand(const char * const *argv, int noWait)
 {
     notImplementedWarning_("csoundRunCommand");
@@ -181,7 +182,7 @@ PUBLIC void csoundSleep(size_t milliseconds)
 
 #define BARRIER_SERIAL_THREAD (-1)
 
-#if !defined(HAVE_PTHREAD_BARRIER_INIT) 
+#if !defined(HAVE_PTHREAD_BARRIER_INIT)
 #ifndef __MACH__
 
 typedef struct barrier {
@@ -224,7 +225,7 @@ PUBLIC uintptr_t csoundJoinThread(void *thread)
     }
 }
 
-#if defined(LINUX) || defined(WIN32)
+#if !defined(ANDROID) && (defined(LINUX) || defined(WIN32))
 
 PUBLIC void *csoundCreateThreadLock(void)
 {
@@ -550,6 +551,11 @@ PUBLIC void csoundDestroyMutex(void *mutex_)
 
 #else
 
+static CS_NOINLINE void notImplementedWarning_(const char *name)
+{
+    fprintf(stderr, Str("%s() is not implemented on this platform.\n"), name);
+}
+
 PUBLIC void *csoundCreateThread(uintptr_t (*threadRoutine)(void *),
                                 void *userdata)
 {
