@@ -62,12 +62,6 @@ if sys.platform[:3] == 'win':
     customLIBPATH.append(r'C:\utah\opt\fltk-1.1.10\lib')
     customLIBPATH.append(r'C:\utah\opt\fltk-1.1.10\bin')
     ################################################################
-    # If you want to build the image opcodes,
-    # libpng and libz are required.
-    customCPPPATH.append(r'C:\utah\msys\1.0\local\include')
-    customLIBPATH.append(r'C:\utah\msys\1.0\local\lib')
-    customLIBPATH.append(r'C:\utah\msys\1.0\local\bin')
-    ################################################################
     # If you want to build the Python opcodes, the Python interfaces
     # to Csound, or CsoundAC, Python 2.5 is required.
     customCPPPATH.append(r'C:\utah\opt\Python27\include')
@@ -82,6 +76,10 @@ if sys.platform[:3] == 'win':
     # If you want to build CsoundAC, you need the 
     # boost C++ libraries.
     customCPPPATH.append(r'C:\utah\opt\boost_1_47_0')
+    # Also Eigen 3.
+    customCPPPATH.append(r'C:\utah\opt')
+    # Unfortunately Eigen uses #include "" so this too is needed.
+    customCPPPATH.append(r'C:\utah\opt\eigen3\Eigen')
     ################################################################
     # If you want to build scoregen, you need the include
     # path to VST MIDI plugin SDK header files. 
@@ -137,13 +135,22 @@ if sys.platform[:3] == 'win':
     ################################################################
     # If you want to build MusicXML import and export, 
     # you need the MusicXML library.
-        # Add it here (the CodeBlocks build seems to work).
+    # Add it here (the CodeBlocks build seems to work).
     customCPPPATH.append(r'C:\utah\opt\musicxml-v2\src\elements') 
     customCPPPATH.append(r'C:\utah\opt\musicxml-v2\src\files') 
     customCPPPATH.append(r'C:\utah\opt\musicxml-v2\src\visitors') 
     customCPPPATH.append(r'C:\utah\opt\musicxml-v2\src\lib') 
     customCPPPATH.append(r'C:\utah\opt\musicxml-v2\src\parser') 
     customLIBPATH.append(r'C:\utah\opt\musicxml-v2\win32\codeblocks')
+    ################################################################
+    # If you want to build the image opcodes,
+    # libpng and libz are required.
+    customCPPPATH.append(r'C:\utah\opt\mingw\msys\1.0\include')
+    customLIBPATH.append(r'C:\utah\opt\mingw\msys\1.0\lib')
+    customLIBPATH.append(r'C:\utah\opt\mingw\msys\1.0\bin')
+    customCPPPATH.append(r'C:\utah\opt\mingw\msys\1.0\local\include')
+    customLIBPATH.append(r'C:\utah\opt\mingw\msys\1.0\local\lib')
+    customLIBPATH.append(r'C:\utah\opt\mingw\msys\1.0\local\bin')
     # print "Adding custom path."
 else:
     platform = 'unsupported platform'
