@@ -21,6 +21,8 @@
 #include "Exception.hpp"
 #include "Composition.hpp"
 #include "System.hpp"
+#include <cstdio>
+#include <cstdlib>
 
 namespace csound
 {
@@ -38,21 +40,26 @@ namespace csound
   {
   }
 
-  void MusicModel::generate()
+  int MusicModel::generate()
   {
+    int errorStatus = 0;
     cppSound->removeScore();
     if (children.size()) {
       score.clear();
     }
     traverse(getLocalCoordinates(), score);
     System::message("Generated %d events.\n", score.size());
+    return errorStatus;
   }
 
-  void MusicModel::render()
+  int MusicModel::render()
   {
-    generate();
-    createCsoundScore(csoundScoreHeader);
-    perform();
+    int errorStatus = generate();
+    if (errorStatus) {
+      return errorStatus;
+    }
+    errorStatus = perform();
+    return errorStatus;
   }
 
   void MusicModel::createCsoundScore(std::string addToScore, double extendSeconds)
@@ -66,22 +73,30 @@ namespace csound
     char buffer[0x100];
     std::sprintf(buffer, "\ns %9.3f", extendSeconds);
     cppSound->addScoreLine(buffer);
-    std::sprintf(buffer, "\ne %9.3f", extendSeconds);
-    cppSound->addScoreLine(buffer);
+    //std::sprintf(buffer, "\ne %9.3f", extendSeconds);
+    //cppSound->addScoreLine(buffer);
     cppSound->exportForPerformance();
   }
 
-  void MusicModel::perform()
+  int MusicModel::perform()
   {
-    cppSound->perform();
+    int errorStatus = 0;
+    cppSound->setCommand(getCsoundCommand());
+    createCsoundScore(csoundScoreHeader);
+    errorStatus = cppSound->perform();
+    if (errorStatus == 1) {
+      errorStatus = 0;
+    }
+    // The Csound command is managed from MusicModel,
+    // not from CppSound. So we clear out what we set.
+    cppSound->setCommand("");
+    return errorStatus;
   }
 
-
-
   void MusicModel::clear()
   {
     Node::clear();
-    MusicModel::clear();
+    Composition::clear();
     cppSound->removeScore();
   }
 
@@ -128,16 +143,16 @@ namespace csound
   }
 
   void MusicModel::arrange(int oldInstrumentNumber,
-                            int newInstrumentNumber,
-                            double gain)
+                           int newInstrumentNumber,
+                           double gain)
   {
     score.arrange(oldInstrumentNumber, newInstrumentNumber, gain);
   }
 
   void MusicModel::arrange(int oldInstrumentNumber,
-                            int newInstrumentNumber,
-                            double gain,
-                            double pan)
+                           int newInstrumentNumber,
+                           double gain,
+                           double pan)
   {
     score.arrange(oldInstrumentNumber, newInstrumentNumber, gain, pan);
   }
@@ -152,7 +167,7 @@ namespace csound
   {
     int csoundInstrumentNumber = cppSound->getInstrumentNumber(csoundInstrumentName);
     arrange(silenceInstrumentNumber, csoundInstrumentNumber, gain);
-   }
+  }
 
   void MusicModel::arrange(int silenceInstrumentNumber, std::string csoundInstrumentName, double gain, double pan)
   {
@@ -172,41 +187,23 @@ namespace csound
 
   std::string MusicModel::getCsoundCommand() const
   {
-    return cppSound->getCommand();
-  }
-
-  std::string MusicModel::getFilename() const
-  {
-    return filename;
-  }
-
-  void MusicModel::setFilename(std::string filename)
-  {
-    this->filename = filename;
-  }
-
-  std::string MusicModel::generateFilename()
-  {
-    time_t time_ = 0;
-    time(&time_);
-    struct tm* tm_ = gmtime(&time_);
-    char buffer[0x100];
-    strftime(buffer, 0x100, "silence.%Y-%m-%d.%H-%M-%S.py", tm_);
-    return buffer;
-  }
-
-  std::string MusicModel::getMidiFilename()
-  {
-    std::string name = getFilename();
-    name.append(".mid");
-    return name;
-  }
-
-  std::string MusicModel::getOutputSoundfileName()
-  {
-    std::string name = getFilename();
-    name.append(".wav");
-    return name;
+    std::string command_ = cppSound->getCommand();
+    if (command_.size() == 0)
+      {
+        const char *temp_path = std::getenv("TEMP");
+        if (temp_path == 0)
+          {
+            temp_path = "";
+          }
+        std::string orcname = std::tmpnam(0);
+        std::string sconame = std::tmpnam(0);
+        char buffer[0x200];
+        std::sprintf(buffer,
+                     "csound --midi-key=4 --midi-velocity=5 -m195 -RWdfo %s %s%s.orc %s%s.sco",
+                     getOutputSoundfileName().c_str(), temp_path, orcname.c_str(), temp_path, sconame.c_str());
+        command_ = buffer;
+      }
+    return command_;
   }
 
   long MusicModel::getThis()
@@ -219,5 +216,80 @@ namespace csound
     return (Node *)this;
   }
 
-}
+  int MusicModel::processArgs(const std::vector<std::string> &args)
+  {
+    System::inform("BEGAN MusicModel::processArgv()...\n");
+    std::map<std::string, std::string> argsmap;
+    std::string key;
+    for (size_t i = 0, n = args.size(); i < n; ++i)
+      {
+	const std::string token = args[i];
+	std::string value = "";
+	if (token.find("--") == 0) 
+	  {
+	    key = token;
+	  }
+	else
+	  {
+	    value = token;
+	  }
+	argsmap[key] = value;
+	System::inform("argument[%2d]: %s =  %s\n", i, key.c_str(), value.c_str());
+      }
+    char command[0x200];
+    int errorStatus = 0;
+    bool postPossible = false;
+    std::string playSoundfileName = getOutputSoundfileName();
+    if ((argsmap.find("--midi") != argsmap.end()) && !errorStatus)
+      {
+        errorStatus = generate();
+	if (errorStatus) {
+	  return errorStatus;
+	}
+        getScore().save(getMidiFilename().c_str());
+      }
+    if ((argsmap.find("--csound") != argsmap.end()) && !errorStatus)
+      {
+        postPossible = true;
+        errorStatus = render();
+      }
+    if ((argsmap.find("--pianoteq") != argsmap.end()) && !errorStatus)
+      {
+        std::sprintf(command, "Pianoteq --midi %s\n", getMidiFilename().c_str());
+	System::inform("Executing command: %s", command);
+        errorStatus = std::system(command);
+      }
+    if ((argsmap.find("--pianoteq-wav") != argsmap.end()) && !errorStatus)
+      {
+        postPossible = true;
+        std::sprintf(command, "Pianoteq --headless --midi %s --rate 48000 --wav %s\n", getMidiFilename().c_str(), getOutputSoundfileName().c_str());
+	System::inform("Executing command: %s", command);
+        errorStatus = std::system(command);
+      }
+    if ((argsmap.find("--playmidi") != argsmap.end()) && !errorStatus)
+      {
+        std::sprintf(command, "%s %s\n", argsmap["--playmidi"].c_str(), getMidiFilename().c_str());
+	System::inform("Executing command: %s", command);
+        errorStatus = std::system(command);
+      }
+    if ((argsmap.find("--post") != argsmap.end()) && !errorStatus && postPossible)
+      {
+        errorStatus = translateMaster();
+	playSoundfileName = getNormalizedSoundfileName();
+      }
+    if ((argsmap.find("--playwav") != argsmap.end()) && !errorStatus)
+      {
+        std::sprintf(command, "%s %s\n", argsmap["--playwav"].c_str(), playSoundfileName.c_str());
+	System::inform("Executing command: %s", command);
+        errorStatus = std::system(command);
+      }
+    System::inform("ENDED MusicModel::processArgv().\n");
+    return errorStatus;
+  }
 
+  void MusicModel::stop()
+  {
+    std::cout << "MusicModel::stop()..." << std::endl;
+    cppSound->stop();
+  }
+}
