@@ -184,8 +184,8 @@ void Compile(globals *g)
                    &actualsize);
     text[actualsize] = '\0';
     dir = SetWorkingDirectory(g);
-    if (DEBUG)
-      fprintf(stderr, "text event: %s %d\n");
+    /* if (DEBUG) */
+    /*   fprintf(stderr, "text event: %s %d\n", text, actualsize); */
     tmp[0] = "csound";
     TextSplitter(text, &tmp[1], &args);
     for (i = 1; i < args + 1; i++)
