@@ -53,15 +53,15 @@ Fl_Text_Buffer     *textbuf = 0;
 // Syntax highlighting stuff...
 Fl_Text_Buffer     *stylebuf = 0;
 Fl_Text_Display::Style_Table_Entry
-                  styletable[] = {      // Style table
-                     { FL_BLACK,      FL_COURIER,        14 }, // A - Plain
-                     { FL_DARK_GREEN, FL_COURIER_ITALIC, 14 }, // B - Line comments
-                     { FL_DARK_GREEN, FL_COURIER_ITALIC, 14 }, // C - Block comments
-                     { FL_RED,        FL_COURIER,        14 }, // D - Strings
-                     { FL_DARK_RED,   FL_COURIER,        14 }, // E - Directives
-                     { FL_DARK_RED,   FL_COURIER_BOLD,   14 }, // F - Types
-                     { FL_BLUE,       FL_COURIER_BOLD,   14 }  // G - Keywords
-                   };
+styletable[] = {      // Style table
+                 { FL_BLACK,      FL_COURIER,        14 }, // A - Plain
+                 { FL_DARK_GREEN, FL_COURIER_ITALIC, 14 }, // B - Line comments
+                 { FL_DARK_GREEN, FL_COURIER_ITALIC, 14 }, // C - Block comments
+                 { FL_RED,        FL_COURIER,        14 }, // D - Strings
+                 { FL_DARK_RED,   FL_COURIER,        14 }, // E - Directives
+                 { FL_DARK_RED,   FL_COURIER_BOLD,   14 }, // F - Types
+                 { FL_BLUE,       FL_COURIER_BOLD,   14 }  // G - Keywords
+};
 
 const char         *code_keywords[] = { // List of known C/C++ keywords...
             "ATSadd",
@@ -203,7 +203,7 @@ const char         *code_keywords[] = { // List of known C/C++ keywords...
             "cpuprc",
             "cross2",
             "crunch",
-                "ctrl",
+            "ctrl",
             "ctrl7",
             "ctrl14",
             "ctrl21",
@@ -249,7 +249,7 @@ const char         *code_keywords[] = { // List of known C/C++ keywords...
             "event_i",
             "exitnow",
             "exp",
-                "expcurve",
+            "expcurve",
             "expon",
             "exprand",
             "expseg",
@@ -315,7 +315,7 @@ const char         *code_keywords[] = { // List of known C/C++ keywords...
             "ftsavek",
             "ftsr",
             "gain",
-                "gainslider",
+            "gainslider",
             "gauss",
             "gbuzz",
             "getcfg",
@@ -369,7 +369,7 @@ const char         *code_keywords[] = { // List of known C/C++ keywords...
             "log",
             "log10",
             "logbtwo",
-                "logcurve",
+            "logcurve",
             "loop_ge",
             "loop_gt",
             "loop_le",
@@ -440,12 +440,12 @@ const char         *code_keywords[] = { // List of known C/C++ keywords...
             "minaccum",
             "mirror",
             "mod",
-                "mode",
+            "mode",
             "monitor",
             "moog",
             "moogladder",
             "moogvcf",
-                "moogvcf2",
+            "moogvcf2",
             "moscil",
             "mpulse",
             "mrtmsg",
@@ -569,30 +569,30 @@ const char         *code_keywords[] = { // List of known C/C++ keywords...
             "pvsadsyn",
             "pvsanal",
             "pvsarp",
-                "pvsbin",
+            "pvsbin",
             "pvsblur",
             "pvscale",
             "pvscent",
             "pvscross",
             "pvsdemix",
-                "pvsdisp",
+            "pvsdisp",
             "pvsfilter",
             "pvsfread",
             "pvsfreeze",
             "pvsftr",
             "pvsftw",
-                "pvsfwrite",
+            "pvsfwrite",
             "pvshift",
             "pvsifd",
-                "pvsin",
+            "pvsin",
             "pvsinfo",
             "pvsinit",
             "pvsmaska",
             "pvsmix",
             "pvsmooth",
-                "pvsosc",
-                "pvsout",
-                "pvspitch",
+            "pvsosc",
+            "pvsout",
+            "pvspitch",
             "pvstencil",
             "pvsvoc",
             "pvsynth",
@@ -719,7 +719,7 @@ const char         *code_keywords[] = { // List of known C/C++ keywords...
             "s32b14",
             "samphold",
             "sandpaper",
-                "scale",
+            "scale",
             "scanhammer",
             "scans",
             "scantable",
@@ -930,12 +930,12 @@ const char         *code_keywords[] = { // List of known C/C++ keywords...
             "upsamp",
             "urd",
             "vadd",
-                "vadd_i",
+            "vadd_i",
             "vaddv",
-                "vaddv_i",
-                "vaget",
+            "vaddv_i",
+            "vaget",
             "valpass",
-                "vaset",
+            "vaset",
             "vbap16",
             "vbap16move",
             "vbap4",
@@ -1100,19 +1100,19 @@ const char         *code_types[] = {     // csd tags
                    "FLvalue",
                    "ctrlinit",
                    "else",
-               "elseif",
+                   "elseif",
                    "endif",
-           "ftgen",
+                   "ftgen",
                    "if",
-           "kr",
-           "ksmps",
-           "massign",
-           "nchnls",
-           "pgmassign",
-           "pset",
-           "seed",
-           "sr",
-           "strset",
+                   "kr",
+                   "ksmps",
+                   "massign",
+                   "nchnls",
+                   "pgmassign",
+                   "pset",
+                   "seed",
+                   "sr",
+                   "strset",
                    "then"
                    };
 
@@ -1122,11 +1122,11 @@ const char         *code_types[] = {     // csd tags
 //
 
 extern "C" {
- int
- compare_keywords(const void *a,
-                  const void *b) {
-   return (strcmp(*((const char **)a), *((const char **)b)));
- }
+  int
+  compare_keywords(const void *a,
+                   const void *b) {
+      return (strcmp(*((const char **)a), *((const char **)b)));
+  }
 }
 
 //
@@ -1135,14 +1135,13 @@ extern "C" {
 
 void
 style_parse(const char *text,
-           char       *style,
+            char       *style,
             int        length) {
- char        current;
- int         col;
- int         last;
- char        buf[255],
-            *bufptr;
- const char *temp;
+    char        current;
+    int         col;
+    int         last;
+    char        buf[255], *bufptr;
+    const char *temp;
 
  // Style letters:
  //
@@ -1154,34 +1153,37 @@ style_parse(const char *text,
  // F - Types
  // G - Keywords
 
- for (current = *style, col = 0, last = 0; length > 0; length --, text ++) {
-   if (current == 'B' || current == 'F' || current == 'G') current = 'A';
-   if (current == 'A') {
-     // Check for directives, comments, strings, and keywords...
-     if (col == 0 && (*text == '#' || *text == '<')) {
-       // Set style to directive
-       current = 'E';
-     } else if (strncmp(text, ";", 1) == 0) {
-       current = 'B';
-        for (; length > 0 && *text != '\n'; length --, text ++) *style++ = 'B';
+   for (current = *style, col = 0, last = 0; length > 0; length --, text ++) {
+     if (current == 'B' || current == 'F' || current == 'G') current = 'A';
+     if (current == 'A') {
+       // Check for directives, comments, strings, and keywords...
+       if (col == 0 && (*text == '#' || *text == '<')) {
+         // Set style to directive
+         current = 'E';
+       } else if (strncmp(text, ";", 1) == 0) {
+         current = 'B';
+         for (; length > 0 && *text != '\n'; length --, text ++) *style++ = 'B';
 
-       if (length == 0) break;
-     } else if (strncmp(text, "/*", 2) == 0) {
-       current = 'C';
-     } else if (strncmp(text, "\\\"", 2) == 0) {
-       // Quoted quote...
-        *style++ = current;
-        *style++ = current;
-        text ++;
-        length --;
-        col += 2;
-        continue;
-     } else if (*text == '\"') {
-       current = 'D';
-     } else if (!last && (( islower(*text) || isupper(*text) ) || *text == '_')) {
-       // Might be a keyword...
-        for (temp = text, bufptr = buf;
-             (( islower(*temp) || isupper(*temp) ) || *temp == '_') && bufptr < (buf + sizeof(buf) - 1);
+         if (length == 0) break;
+       } else if (strncmp(text, "/*", 2) == 0) {
+         current = 'C';
+       } else if (strncmp(text, "\\\"", 2) == 0) {
+         // Quoted quote...
+         *style++ = current;
+         *style++ = current;
+         text ++;
+         length --;
+         col += 2;
+         continue;
+       } else if (*text == '\"') {
+         current = 'D';
+       } else if (!last && (( islower(*text) || isupper(*text) ) ||
+                            *text == '_')) {
+         // Might be a keyword...
+         for (temp = text, bufptr = buf;
+              (( islower(*temp)   ||
+                 isupper(*temp) ) ||
+               *temp == '_') && bufptr < (buf + sizeof(buf) - 1);
              *bufptr++ = *temp++);
 
        if (!( islower(*temp) || isupper(*temp) ) && *temp != '_') {
@@ -1270,20 +1272,20 @@ style_parse(const char *text,
 
 void
 style_init(void) {
- char *style = new char[textbuf->length() + 1];
- char *text = textbuf->text();
+    char *style = new char[textbuf->length() + 1];
+    char *text = textbuf->text();
 
 
- memset(style, 'A', textbuf->length());
- style[textbuf->length()] = '\0';
+    memset(style, 'A', textbuf->length());
+    style[textbuf->length()] = '\0';
 
- if (!stylebuf) stylebuf = new Fl_Text_Buffer(textbuf->length());
+    if (!stylebuf) stylebuf = new Fl_Text_Buffer(textbuf->length());
 
- style_parse(text, style, textbuf->length());
+    style_parse(text, style, textbuf->length());
 
- stylebuf->text(style);
- delete[] style;
- free(text);
+    stylebuf->text(style);
+    delete[] style;
+    free(text);
 }
 
 
@@ -1302,88 +1304,88 @@ style_unfinished_cb(int, void*) {
 
 void
 style_update(int        pos,            // I - Position of update
-            int        nInserted,       // I - Number of inserted chars
+             int        nInserted,       // I - Number of inserted chars
              int        nDeleted,       // I - Number of deleted chars
-            int        /*nRestyled*/,   // I - Number of restyled chars
+             int        /*nRestyled*/,   // I - Number of restyled chars
              const char * /*deletedText*/,// I - Text that was deleted
-            void       *cbArg) {        // I - Callback data
- int    start,                          // Start of text
-        end;                            // End of text
- char   last,                           // Last style on line
-        *style,                         // Style data
-        *text;                          // Text data
+             void       *cbArg) {        // I - Callback data
+    int    start,                          // Start of text
+           end;                            // End of text
+    char   last,                           // Last style on line
+           *style,                         // Style data
+           *text;                          // Text data
 
 
  // If this is just a selection change, just unselect the style buffer...
- if (nInserted == 0 && nDeleted == 0) {
-   stylebuf->unselect();
-   return;
- }
+    if (nInserted == 0 && nDeleted == 0) {
+      stylebuf->unselect();
+      return;
+    }
 
- // Track changes in the text buffer...
- if (nInserted > 0) {
-   // Insert characters into the style buffer...
-   style = new char[nInserted + 1];
-   memset(style, 'A', nInserted);
-   style[nInserted] = '\0';
+    // Track changes in the text buffer...
+    if (nInserted > 0) {
+      // Insert characters into the style buffer...
+      style = new char[nInserted + 1];
+      memset(style, 'A', nInserted);
+      style[nInserted] = '\0';
 
-   stylebuf->replace(pos, pos + nDeleted, style);
-   delete[] style;
- } else {
-   // Just delete characters in the style buffer...
-   stylebuf->remove(pos, pos + nDeleted);
- }
+      stylebuf->replace(pos, pos + nDeleted, style);
+      delete[] style;
+    } else {
+      // Just delete characters in the style buffer...
+      stylebuf->remove(pos, pos + nDeleted);
+    }
 
- // Select the area that was just updated to avoid unnecessary
- // callbacks...
- stylebuf->select(pos, pos + nInserted - nDeleted);
+    // Select the area that was just updated to avoid unnecessary
+    // callbacks...
+    stylebuf->select(pos, pos + nInserted - nDeleted);
 
- // Re-parse the changed region; we do this by parsing from the
- // beginning of the previous line of the changed region to the end of
- // the line of the changed region...  Then we check the last
- // style character and keep updating if we have a multi-line
- // comment character...
- start = textbuf->line_start(pos);
-//  if (start > 0) start = textbuf->line_start(start - 1);
- end   = textbuf->line_end(pos + nInserted);
- text  = textbuf->text_range(start, end);
- style = stylebuf->text_range(start, end);
- if (start==end)
-   last = 0;
- else
-   last  = style[end - start - 1];
+    // Re-parse the changed region; we do this by parsing from the
+    // beginning of the previous line of the changed region to the end of
+    // the line of the changed region...  Then we check the last
+    // style character and keep updating if we have a multi-line
+    // comment character...
+    start = textbuf->line_start(pos);
+    //  if (start > 0) start = textbuf->line_start(start - 1);
+    end   = textbuf->line_end(pos + nInserted);
+    text  = textbuf->text_range(start, end);
+    style = stylebuf->text_range(start, end);
+    if (start==end)
+      last = 0;
+    else
+      last  = style[end - start - 1];
 
 //  printf("start = %d, end = %d, text = \"%s\", style = \"%s\", last='%c'...\n",
 //         start, end, text, style, last);
 
- style_parse(text, style, end - start);
+    style_parse(text, style, end - start);
 
 //  printf("new style = \"%s\", new last='%c'...\n",
 //         style, style[end - start - 1]);
 
- stylebuf->replace(start, end, style);
- ((Fl_Text_Editor *)cbArg)->redisplay_range(start, end);
+    stylebuf->replace(start, end, style);
+    ((Fl_Text_Editor *)cbArg)->redisplay_range(start, end);
 
- if (start==end || last != style[end - start - 1]) {
+    if (start==end || last != style[end - start - 1]) {
 //    printf("Recalculate the rest of the buffer style\n");
    // Either the user deleted some text, or the last character
    // on the line changed styles, so reparse the
    // remainder of the buffer...
-   free(text);
-   free(style);
+      free(text);
+      free(style);
 
-   end   = textbuf->length();
-   text  = textbuf->text_range(start, end);
-   style = stylebuf->text_range(start, end);
+      end   = textbuf->length();
+      text  = textbuf->text_range(start, end);
+      style = stylebuf->text_range(start, end);
 
-   style_parse(text, style, end - start);
+      style_parse(text, style, end - start);
 
-   stylebuf->replace(start, end, style);
-   ((Fl_Text_Editor *)cbArg)->redisplay_range(start, end);
- }
+      stylebuf->replace(start, end, style);
+      ((Fl_Text_Editor *)cbArg)->redisplay_range(start, end);
+    }
 
- free(text);
- free(style);
+    free(text);
+    free(style);
 }
 
 
@@ -1396,369 +1398,369 @@ void replace2_cb(Fl_Widget*, void*);
 void replcan_cb(Fl_Widget*, void*);
 
 class EditorWindow : public Fl_Double_Window {
- public:
-   EditorWindow(int w, int h, const char* t);
-   ~EditorWindow();
+public:
+  EditorWindow(int w, int h, const char* t);
+  ~EditorWindow();
 
-   Fl_Window          *replace_dlg;
-   Fl_Input           *replace_find;
-   Fl_Input           *replace_with;
-   Fl_Button          *replace_all;
-   Fl_Return_Button   *replace_next;
-   Fl_Button          *replace_cancel;
+  Fl_Window          *replace_dlg;
+  Fl_Input           *replace_find;
+  Fl_Input           *replace_with;
+  Fl_Button          *replace_all;
+  Fl_Return_Button   *replace_next;
+  Fl_Button          *replace_cancel;
 
-   Fl_Text_Editor     *editor;
-   char               search[256];
+  Fl_Text_Editor     *editor;
+  char               search[256];
 };
 
 EditorWindow::EditorWindow(int w, int h, const char* t) :
-Fl_Double_Window(w, h, t) {
- replace_dlg = new Fl_Window(300, 105, "Replace");
-   replace_find = new Fl_Input(80, 10, 210, 25, "Find:");
-   replace_find->align(FL_ALIGN_LEFT);
+  Fl_Double_Window(w, h, t) {
+    replace_dlg = new Fl_Window(300, 105, "Replace");
+    replace_find = new Fl_Input(80, 10, 210, 25, "Find:");
+    replace_find->align(FL_ALIGN_LEFT);
 
-   replace_with = new Fl_Input(80, 40, 210, 25, "Replace:");
-   replace_with->align(FL_ALIGN_LEFT);
+    replace_with = new Fl_Input(80, 40, 210, 25, "Replace:");
+    replace_with->align(FL_ALIGN_LEFT);
 
-   replace_all = new Fl_Button(10, 70, 90, 25, "Replace All");
-   replace_all->callback((Fl_Callback *)replall_cb, this);
+    replace_all = new Fl_Button(10, 70, 90, 25, "Replace All");
+    replace_all->callback((Fl_Callback *)replall_cb, this);
 
-   replace_next = new Fl_Return_Button(105, 70, 120, 25, "Replace Next");
-   replace_next->callback((Fl_Callback *)replace2_cb, this);
+    replace_next = new Fl_Return_Button(105, 70, 120, 25, "Replace Next");
+    replace_next->callback((Fl_Callback *)replace2_cb, this);
 
-   replace_cancel = new Fl_Button(230, 70, 60, 25, "Cancel");
-   replace_cancel->callback((Fl_Callback *)replcan_cb, this);
- replace_dlg->end();
- replace_dlg->set_non_modal();
- editor = 0;
- *search = (char)0;
+    replace_cancel = new Fl_Button(230, 70, 60, 25, "Cancel");
+    replace_cancel->callback((Fl_Callback *)replcan_cb, this);
+    replace_dlg->end();
+    replace_dlg->set_non_modal();
+    editor = 0;
+    *search = (char)0;
 }
 
 EditorWindow::~EditorWindow() {
- delete replace_dlg;
+    delete replace_dlg;
 }
 
 int check_save(void) {
- if (!changed) return 1;
+    if (!changed) return 1;
 
- int r = fl_choice("The current file has not been saved.\n"
-                   "Would you like to save it now?",
-                   "Cancel", "Save", "Don't Save");
+    int r = fl_choice("The current file has not been saved.\n"
+                      "Would you like to save it now?",
+                      "Cancel", "Save", "Don't Save");
 
- if (r == 1) {
-   save_cb(); // Save the file...
-   return !changed;
- }
+    if (r == 1) {
+      save_cb(); // Save the file...
+      return !changed;
+    }
 
- return (r == 2) ? 1 : 0;
+    return (r == 2) ? 1 : 0;
 }
 
 int loading = 0;
 void load_file(char *newfile, int ipos) {
- loading = 1;
- int insert = (ipos != -1);
- changed = insert;
- if (!insert) strcpy(filename, "");
- int r;
- if (!insert) r = textbuf->loadfile(newfile);
- else r = textbuf->insertfile(newfile, ipos);
- if (r)
-   fl_alert("Error reading from file \'%s\':\n%s.", newfile, strerror(errno));
- else
-   if (!insert) strcpy(filename, newfile);
- loading = 0;
- textbuf->call_modify_callbacks();
+    loading = 1;
+    int insert = (ipos != -1);
+    changed = insert;
+    if (!insert) strcpy(filename, "");
+    int r;
+    if (!insert) r = textbuf->loadfile(newfile);
+    else r = textbuf->insertfile(newfile, ipos);
+    if (r)
+      fl_alert("Error reading from file \'%s\':\n%s.", newfile, strerror(errno));
+    else
+      if (!insert) strcpy(filename, newfile);
+    loading = 0;
+    textbuf->call_modify_callbacks();
 }
 
 void save_file(char *newfile) {
- if (textbuf->savefile(newfile))
-   fl_alert("Error writing to file \'%s\':\n%s.", newfile, strerror(errno));
- else
-   strcpy(filename, newfile);
- changed = 0;
- textbuf->call_modify_callbacks();
+    if (textbuf->savefile(newfile))
+      fl_alert("Error writing to file \'%s\':\n%s.", newfile, strerror(errno));
+    else
+      strcpy(filename, newfile);
+    changed = 0;
+    textbuf->call_modify_callbacks();
 }
 
 void copy_cb(Fl_Widget*, void* v) {
- EditorWindow* e = (EditorWindow*)v;
- Fl_Text_Editor::kf_copy(0, e->editor);
+    EditorWindow* e = (EditorWindow*)v;
+    Fl_Text_Editor::kf_copy(0, e->editor);
 }
 
 void cut_cb(Fl_Widget*, void* v) {
- EditorWindow* e = (EditorWindow*)v;
- Fl_Text_Editor::kf_cut(0, e->editor);
+    EditorWindow* e = (EditorWindow*)v;
+    Fl_Text_Editor::kf_cut(0, e->editor);
 }
 
 void delete_cb(Fl_Widget*, void*) {
- textbuf->remove_selection();
+    textbuf->remove_selection();
 }
 
 void find_cb(Fl_Widget* w, void* v) {
- EditorWindow* e = (EditorWindow*)v;
- const char *val;
+    EditorWindow* e = (EditorWindow*)v;
+    const char *val;
 
- val = fl_input("Search String:", e->search);
- if (val != NULL) {
-   // User entered a string - go find it!
-   strcpy(e->search, val);
-   find2_cb(w, v);
- }
+    val = fl_input("Search String:", e->search);
+    if (val != NULL) {
+      // User entered a string - go find it!
+      strcpy(e->search, val);
+      find2_cb(w, v);
+    }
 }
 
 void find2_cb(Fl_Widget* w, void* v) {
- EditorWindow* e = (EditorWindow*)v;
- if (e->search[0] == '\0') {
-   // Search string is blank; get a new one...
-   find_cb(w, v);
-   return;
- }
+    EditorWindow* e = (EditorWindow*)v;
+    if (e->search[0] == '\0') {
+      // Search string is blank; get a new one...
+      find_cb(w, v);
+      return;
+    }
 
- int pos = e->editor->insert_position();
- int found = textbuf->search_forward(pos, e->search, &pos);
- if (found) {
-   // Found a match; select and update the position...
-   textbuf->select(pos, pos+strlen(e->search));
-   e->editor->insert_position(pos+strlen(e->search));
-   e->editor->show_insert_position();
- }
- else fl_alert("No occurrences of \'%s\' found!", e->search);
+    int pos = e->editor->insert_position();
+    int found = textbuf->search_forward(pos, e->search, &pos);
+    if (found) {
+      // Found a match; select and update the position...
+      textbuf->select(pos, pos+strlen(e->search));
+      e->editor->insert_position(pos+strlen(e->search));
+      e->editor->show_insert_position();
+    }
+    else fl_alert("No occurrences of \'%s\' found!", e->search);
 }
 
 void set_title(Fl_Window* w) {
- if (filename[0] == '\0') strcpy(title, "Untitled");
- else {
-   char *slash;
-   slash = strrchr(filename, '/');
+    if (filename[0] == '\0') strcpy(title, "Untitled");
+    else {
+      char *slash;
+      slash = strrchr(filename, '/');
 #ifdef WIN32
-   if (slash == NULL) slash = strrchr(filename, '\\');
+      if (slash == NULL) slash = strrchr(filename, '\\');
 #endif
-   if (slash != NULL) strcpy(title, slash + 1);
-   else strcpy(title, filename);
- }
+      if (slash != NULL) strcpy(title, slash + 1);
+      else strcpy(title, filename);
+    }
 
- if (changed) strcat(title, " (modified)");
+    if (changed) strcat(title, " (modified)");
 
- w->label(title);
+    w->label(title);
 }
 
 void changed_cb(int, int nInserted, int nDeleted,int, const char*, void* v) {
- if ((nInserted || nDeleted) && !loading) changed = 1;
- EditorWindow *w = (EditorWindow *)v;
- set_title(w);
- if (loading) w->editor->show_insert_position();
+    if ((nInserted || nDeleted) && !loading) changed = 1;
+    EditorWindow *w = (EditorWindow *)v;
+    set_title(w);
+    if (loading) w->editor->show_insert_position();
 }
 
 void new_cb(Fl_Widget*, void*) {
- if (!check_save()) return;
+    if (!check_save()) return;
 
- filename[0] = '\0';
- textbuf->select(0, textbuf->length());
- textbuf->remove_selection();
- changed = 0;
- textbuf->call_modify_callbacks();
+    filename[0] = '\0';
+    textbuf->select(0, textbuf->length());
+    textbuf->remove_selection();
+    changed = 0;
+    textbuf->call_modify_callbacks();
 }
 
 void open_cb(Fl_Widget*, void*) {
- if (!check_save()) return;
+    if (!check_save()) return;
 
- char *newfile = fl_file_chooser("Open File?", "*", filename);
- if (newfile != NULL) load_file(newfile, -1);
+    char *newfile = fl_file_chooser("Open File?", "*", filename);
+    if (newfile != NULL) load_file(newfile, -1);
 }
 
 void insert_cb(Fl_Widget*, void *v) {
- char *newfile = fl_file_chooser("Insert File?", "*", filename);
- EditorWindow *w = (EditorWindow *)v;
- if (newfile != NULL) load_file(newfile, w->editor->insert_position());
+    char *newfile = fl_file_chooser("Insert File?", "*", filename);
+    EditorWindow *w = (EditorWindow *)v;
+    if (newfile != NULL) load_file(newfile, w->editor->insert_position());
 }
 
 void paste_cb(Fl_Widget*, void* v) {
- EditorWindow* e = (EditorWindow*)v;
- Fl_Text_Editor::kf_paste(0, e->editor);
+    EditorWindow* e = (EditorWindow*)v;
+    Fl_Text_Editor::kf_paste(0, e->editor);
 }
 
 int num_windows = 0;
 
 void close_cb(Fl_Widget*, void* v) {
- Fl_Window* w = (Fl_Window*)v;
- if (num_windows == 1 && !check_save()) {
-   return;
- }
+    Fl_Window* w = (Fl_Window*)v;
+    if (num_windows == 1 && !check_save()) {
+      return;
+    }
 
- w->hide();
- textbuf->remove_modify_callback(changed_cb, w);
- delete w;
- num_windows--;
- if (!num_windows) exit(0);
+    w->hide();
+    textbuf->remove_modify_callback(changed_cb, w);
+    delete w;
+    num_windows--;
+    if (!num_windows) exit(0);
 }
 
 void quit_cb(Fl_Widget*, void*) {
- if (changed && !check_save())
-   return;
+    if (changed && !check_save())
+      return;
 
- exit(0);
+    exit(0);
 }
 
 void replace_cb(Fl_Widget*, void* v) {
- EditorWindow* e = (EditorWindow*)v;
- e->replace_dlg->show();
+    EditorWindow* e = (EditorWindow*)v;
+    e->replace_dlg->show();
 }
 
 void replace2_cb(Fl_Widget*, void* v) {
- EditorWindow* e = (EditorWindow*)v;
- const char *find = e->replace_find->value();
- const char *replace = e->replace_with->value();
+    EditorWindow* e = (EditorWindow*)v;
+    const char *find = e->replace_find->value();
+    const char *replace = e->replace_with->value();
 
- if (find[0] == '\0') {
-   // Search string is blank; get a new one...
-   e->replace_dlg->show();
-   return;
- }
+    if (find[0] == '\0') {
+      // Search string is blank; get a new one...
+      e->replace_dlg->show();
+      return;
+    }
 
- e->replace_dlg->hide();
+    e->replace_dlg->hide();
 
- int pos = e->editor->insert_position();
- int found = textbuf->search_forward(pos, find, &pos);
+    int pos = e->editor->insert_position();
+    int found = textbuf->search_forward(pos, find, &pos);
 
- if (found) {
-   // Found a match; update the position and replace text...
-   textbuf->select(pos, pos+strlen(find));
-   textbuf->remove_selection();
-   textbuf->insert(pos, replace);
-   textbuf->select(pos, pos+strlen(replace));
-   e->editor->insert_position(pos+strlen(replace));
-   e->editor->show_insert_position();
- }
- else fl_alert("No occurrences of \'%s\' found!", find);
+    if (found) {
+      // Found a match; update the position and replace text...
+      textbuf->select(pos, pos+strlen(find));
+      textbuf->remove_selection();
+      textbuf->insert(pos, replace);
+      textbuf->select(pos, pos+strlen(replace));
+      e->editor->insert_position(pos+strlen(replace));
+      e->editor->show_insert_position();
+    }
+    else fl_alert("No occurrences of \'%s\' found!", find);
 }
 
 void replall_cb(Fl_Widget*, void* v) {
- EditorWindow* e = (EditorWindow*)v;
- const char *find = e->replace_find->value();
- const char *replace = e->replace_with->value();
+    EditorWindow* e = (EditorWindow*)v;
+    const char *find = e->replace_find->value();
+    const char *replace = e->replace_with->value();
 
- find = e->replace_find->value();
- if (find[0] == '\0') {
-   // Search string is blank; get a new one...
-   e->replace_dlg->show();
-   return;
- }
+    find = e->replace_find->value();
+    if (find[0] == '\0') {
+      // Search string is blank; get a new one...
+      e->replace_dlg->show();
+      return;
+    }
 
- e->replace_dlg->hide();
+    e->replace_dlg->hide();
 
- e->editor->insert_position(0);
- int times = 0;
+    e->editor->insert_position(0);
+    int times = 0;
 
- // Loop through the whole string
- for (int found = 1; found;) {
-   int pos = e->editor->insert_position();
-   found = textbuf->search_forward(pos, find, &pos);
+    // Loop through the whole string
+    for (int found = 1; found;) {
+      int pos = e->editor->insert_position();
+      found = textbuf->search_forward(pos, find, &pos);
 
-   if (found) {
-     // Found a match; update the position and replace text...
-     textbuf->select(pos, pos+strlen(find));
-     textbuf->remove_selection();
-     textbuf->insert(pos, replace);
-     e->editor->insert_position(pos+strlen(replace));
-     e->editor->show_insert_position();
-     times++;
-   }
- }
+      if (found) {
+        // Found a match; update the position and replace text...
+        textbuf->select(pos, pos+strlen(find));
+        textbuf->remove_selection();
+        textbuf->insert(pos, replace);
+        e->editor->insert_position(pos+strlen(replace));
+        e->editor->show_insert_position();
+        times++;
+      }
+    }
 
- if (times) fl_message("Replaced %d occurrences.", times);
- else fl_alert("No occurrences of \'%s\' found!", find);
+    if (times) fl_message("Replaced %d occurrences.", times);
+    else fl_alert("No occurrences of \'%s\' found!", find);
 }
 
 void replcan_cb(Fl_Widget*, void* v) {
- EditorWindow* e = (EditorWindow*)v;
- e->replace_dlg->hide();
+    EditorWindow* e = (EditorWindow*)v;
+    e->replace_dlg->hide();
 }
 
 void save_cb() {
- if (filename[0] == '\0') {
-   // No filename - get one!
-   saveas_cb();
-   return;
- }
- else save_file(filename);
+    if (filename[0] == '\0') {
+      // No filename - get one!
+      saveas_cb();
+      return;
+    }
+    else save_file(filename);
 }
 
 void saveas_cb() {
- char *newfile;
+    char *newfile;
 
- newfile = fl_file_chooser("Save File As?", "*", filename);
- if (newfile != NULL) save_file(newfile);
+    newfile = fl_file_chooser("Save File As?", "*", filename);
+    if (newfile != NULL) save_file(newfile);
 }
 
 Fl_Window* new_view();
 
 void view_cb(Fl_Widget*, void*) {
- Fl_Window* w = new_view();
- w->show();
+    Fl_Window* w = new_view();
+    w->show();
 }
 
 Fl_Menu_Item menuitems[] = {
- { "&File",              0, 0, 0, FL_SUBMENU },
-   { "&New File",        0, (Fl_Callback *)new_cb },
-   { "&Open File...",    FL_CTRL + 'o', (Fl_Callback *)open_cb },
-   { "&Insert File...",  FL_CTRL + 'i', (Fl_Callback *)insert_cb, 0,
-FL_MENU_DIVIDER },
-   { "&Save File",       FL_CTRL + 's', (Fl_Callback *)save_cb },
-   { "Save File &As...", FL_CTRL + FL_SHIFT + 's', (Fl_Callback
-*)saveas_cb, 0, FL_MENU_DIVIDER },
-   { "New &View", FL_ALT + 'v', (Fl_Callback *)view_cb, 0 },
-   { "&Close View", FL_CTRL + 'w', (Fl_Callback *)close_cb, 0,
-FL_MENU_DIVIDER },
-   { "E&xit", FL_CTRL + 'q', (Fl_Callback *)quit_cb, 0 },
-   { 0 },
+  { "&File",              0, 0, 0, FL_SUBMENU },
+  { "&New File",        0, (Fl_Callback *)new_cb },
+  { "&Open File...",    FL_CTRL + 'o', (Fl_Callback *)open_cb },
+  { "&Insert File...",  FL_CTRL + 'i', (Fl_Callback *)insert_cb, 0,
+    FL_MENU_DIVIDER },
+  { "&Save File",       FL_CTRL + 's', (Fl_Callback *)save_cb },
+  { "Save File &As...", FL_CTRL + FL_SHIFT + 's',
+    (Fl_Callback *)saveas_cb, 0, FL_MENU_DIVIDER },
+  { "New &View", FL_ALT + 'v', (Fl_Callback *)view_cb, 0 },
+  { "&Close View", FL_CTRL + 'w', (Fl_Callback *)close_cb, 0,
+    FL_MENU_DIVIDER },
+  { "E&xit", FL_CTRL + 'q', (Fl_Callback *)quit_cb, 0 },
+  { 0 },
 
- { "&Edit", 0, 0, 0, FL_SUBMENU },
-   { "Cu&t",        FL_CTRL + 'x', (Fl_Callback *)cut_cb },
-   { "&Copy",       FL_CTRL + 'c', (Fl_Callback *)copy_cb },
-   { "&Paste",      FL_CTRL + 'v', (Fl_Callback *)paste_cb },
-   { "&Delete",     0, (Fl_Callback *)delete_cb },
-   { 0 },
+  { "&Edit", 0, 0, 0, FL_SUBMENU },
+  { "Cu&t",        FL_CTRL + 'x', (Fl_Callback *)cut_cb },
+  { "&Copy",       FL_CTRL + 'c', (Fl_Callback *)copy_cb },
+  { "&Paste",      FL_CTRL + 'v', (Fl_Callback *)paste_cb },
+  { "&Delete",     0, (Fl_Callback *)delete_cb },
+  { 0 },
 
- { "&Search", 0, 0, 0, FL_SUBMENU },
-   { "&Find...",       FL_CTRL + 'f', (Fl_Callback *)find_cb },
-   { "F&ind Again",    FL_CTRL + 'g', find2_cb },
-   { "&Replace...",    FL_CTRL + 'r', replace_cb },
-   { "Re&place Again", FL_CTRL + 't', replace2_cb },
-   { 0 },
+  { "&Search", 0, 0, 0, FL_SUBMENU },
+  { "&Find...",       FL_CTRL + 'f', (Fl_Callback *)find_cb },
+  { "F&ind Again",    FL_CTRL + 'g', find2_cb },
+  { "&Replace...",    FL_CTRL + 'r', replace_cb },
+  { "Re&place Again", FL_CTRL + 't', replace2_cb },
+  { 0 },
 
- { 0 }
+  { 0 }
 };
 
 Fl_Window* new_view() {
- EditorWindow* w = new EditorWindow(660, 400, title);
-   w->begin();
-   Fl_Menu_Bar* m = new Fl_Menu_Bar(0, 0, 660, 30);
-   m->copy(menuitems, w);
-   w->editor = new Fl_Text_Editor(0, 30, 660, 370);
-   w->editor->buffer(textbuf);
-   w->editor->highlight_data(stylebuf, styletable,
-                             sizeof(styletable) / sizeof(styletable[0]),
+    EditorWindow* w = new EditorWindow(660, 400, title);
+    w->begin();
+    Fl_Menu_Bar* m = new Fl_Menu_Bar(0, 0, 660, 30);
+    m->copy(menuitems, w);
+    w->editor = new Fl_Text_Editor(0, 30, 660, 370);
+    w->editor->buffer(textbuf);
+    w->editor->highlight_data(stylebuf, styletable,
+                              sizeof(styletable) / sizeof(styletable[0]),
                               'A', style_unfinished_cb, 0);
-   w->editor->textfont(FL_COURIER);
- w->end();
- w->resizable(w->editor);
- w->callback((Fl_Callback *)close_cb, w);
+    w->editor->textfont(FL_COURIER);
+    w->end();
+    w->resizable(w->editor);
+    w->callback((Fl_Callback *)close_cb, w);
 
- textbuf->add_modify_callback(style_update, w->editor);
- textbuf->add_modify_callback(changed_cb, w);
- textbuf->call_modify_callbacks();
- num_windows++;
- return w;
+    textbuf->add_modify_callback(style_update, w->editor);
+    textbuf->add_modify_callback(changed_cb, w);
+    textbuf->call_modify_callbacks();
+    num_windows++;
+    return w;
 }
 
 int main(int argc, char **argv) {
- textbuf = new Fl_Text_Buffer;
- style_init();
+    textbuf = new Fl_Text_Buffer;
+    style_init();
 
- Fl_Window* window = new_view();
+    Fl_Window* window = new_view();
 
- window->show(1, argv);
+    window->show(1, argv);
 
- if (argc > 1) load_file(argv[1], -1);
+    if (argc > 1) load_file(argv[1], -1);
 
- return Fl::run();
+    return Fl::run();
 }
